--
-- PostgreSQL database dump
--

\connect - postgres

--
-- TOC entry 125 (OID 2396703)
-- Name: plpgsql_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;


--
-- TOC entry 124 (OID 2396704)
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler;


--
-- TOC entry 3 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


\connect - conflux

--
-- TOC entry 5 (OID 2396705)
-- Name: item_id_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE item_id_seq;


--
-- TOC entry 7 (OID 2396707)
-- Name: scrollback_id_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE scrollback_id_seq;


--
-- TOC entry 21 (OID 2396709)
-- Name: access_rights; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE access_rights (
    item_id integer NOT NULL,
    group_id integer NOT NULL,
    right_id smallint NOT NULL,
    treepos bit varying NOT NULL
);


--
-- TOC entry 22 (OID 2396714)
-- Name: access_groups; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE access_groups (
    group_id integer NOT NULL,
    person_id integer NOT NULL
);


--
-- TOC entry 23 (OID 2396716)
-- Name: items; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE items (
    item_id integer DEFAULT nextval('item_id_seq'::text) NOT NULL,
    parent_id integer NOT NULL,
    item_name text NOT NULL,
    item_size integer NOT NULL,
    creator_id integer NOT NULL,
    creator_ip text NOT NULL,
    create_time timestamp with time zone DEFAULT now() NOT NULL,
    editor_id integer NOT NULL,
    editor_ip text NOT NULL,
    edit_time timestamp with time zone DEFAULT now() NOT NULL,
    item_type_id integer NOT NULL,
    is_internal boolean DEFAULT false NOT NULL,
    is_public boolean DEFAULT false NOT NULL,
    is_private boolean DEFAULT false NOT NULL,
    treepos bit varying NOT NULL,
    owner_id integer,
    index_this_item integer DEFAULT 0
);


--
-- TOC entry 9 (OID 2396746)
-- Name: item_type_id_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE item_type_id_seq;


--
-- TOC entry 24 (OID 2396748)
-- Name: item_types; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE item_types (
    item_type_id integer DEFAULT nextval('item_type_id_seq'::text) NOT NULL,
    item_type_name character varying(128) NOT NULL,
    item_type_icon character varying(128)
);


--
-- TOC entry 25 (OID 2396751)
-- Name: sessions; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE sessions (
    session_id integer DEFAULT nextval('session_id_seq'::text) NOT NULL,
    session_key character(16) NOT NULL,
    user_id integer NOT NULL,
    user_ip character varying(16) NOT NULL,
    start_stamp timestamp with time zone DEFAULT now() NOT NULL,
    update_stamp timestamp with time zone DEFAULT now() NOT NULL,
    update_count integer DEFAULT 0 NOT NULL
);


--
-- TOC entry 11 (OID 2396757)
-- Name: session_id_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE session_id_seq;


--
-- TOC entry 26 (OID 2396759)
-- Name: persons; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE persons (
    person_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    first_name text NOT NULL,
    middle_name text,
    last_name text NOT NULL,
    username character varying(64) NOT NULL,
    "password" character(13) NOT NULL,
    phone_work text,
    phone_home text,
    phone_cell text,
    phone_fax text,
    e_mail text,
    is_disabled integer DEFAULT 0 NOT NULL,
    picture text,
    email_notify integer DEFAULT 0 NOT NULL,
    is_deleted integer DEFAULT 0 NOT NULL
);


--
-- TOC entry 27 (OID 2396766)
-- Name: contacts; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE contacts (
    contact_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    first_name text NOT NULL,
    middle_name text,
    last_name text NOT NULL,
    company text,
    department text,
    jobtitle text,
    phone_work text,
    phone_home text,
    phone_cell text,
    phone_fax text,
    e_mail text,
    mailing_address text,
    description text,
    homepage text,
    contact_category text,
    birth_date date,
    contact_sex integer DEFAULT 0,
    e_mail2 text,
    e_mail3 text
);


--
-- TOC entry 28 (OID 2396773)
-- Name: organizations; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE organizations (
    organization_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    organization_name text NOT NULL,
    address text,
    city text,
    state text,
    zipcode text,
    country text,
    website text,
    email text,
    telephone text,
    fax text,
    superuser_id integer
);


--
-- TOC entry 29 (OID 2396779)
-- Name: user_groups; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE user_groups (
    group_id integer DEFAULT nextval('user_groups_seq'::text) NOT NULL,
    group_org_id integer,
    group_name text,
    top_org_id integer
);


--
-- TOC entry 13 (OID 2396785)
-- Name: user_groups_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE user_groups_seq;


--
-- TOC entry 30 (OID 2396787)
-- Name: events; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE events (
    event_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    event_name character varying(256) NOT NULL,
    event_priority text,
    event_activity text,
    start_stamp timestamp with time zone,
    end_stamp timestamp with time zone,
    description text,
    comments text,
    remind_type integer DEFAULT 0,
    remind_time interval,
    related_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    seen_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    accepted_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    rejected_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    repeat_interval integer,
    dayofweek integer,
    dayofmonth integer,
    monthofyear integer,
    repeat_type integer,
    last_reminder timestamp with time zone,
    related_groups integer[] DEFAULT '{}'::integer[] NOT NULL,
    event_flags integer DEFAULT 0 NOT NULL
);


--
-- TOC entry 31 (OID 2396800)
-- Name: emails; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE emails (
    email_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    email_from text NOT NULL,
    email_subject text NOT NULL,
    email_to text NOT NULL,
    email_date timestamp with time zone NOT NULL,
    email_savedate timestamp with time zone DEFAULT now() NOT NULL,
    email_size integer NOT NULL,
    email_flags integer DEFAULT 0 NOT NULL,
    email_message_id text,
    email_contents text NOT NULL,
    email_contacts text,
    email_from_addr text
);


--
-- TOC entry 32 (OID 2396808)
-- Name: efolders; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE efolders (
    efolder_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    efolder_name text NOT NULL,
    efolder_flags integer NOT NULL
);


--
-- TOC entry 33 (OID 2396814)
-- Name: eaccounts; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE eaccounts (
    eaccount_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    eaccount_name text NOT NULL,
    eaccount_user text NOT NULL,
    eaccount_password text NOT NULL,
    eaccount_flags integer NOT NULL
);


--
-- TOC entry 34 (OID 2396820)
-- Name: folders; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE folders (
    folder_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    folder_name character varying(128),
    comments text
);


--
-- TOC entry 35 (OID 2396826)
-- Name: documents; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE documents (
    document_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    filename text NOT NULL,
    title character varying(256) NOT NULL,
    description text,
    comments text,
    author text,
    mime_major text DEFAULT 'application'::text NOT NULL,
    mime_minor text DEFAULT 'binary'::text NOT NULL,
    final_version_id integer,
    doc_category text,
    locker_id integer,
    lock_due timestamp with time zone
);


--
-- TOC entry 36 (OID 2396834)
-- Name: todos; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE todos (
    todo_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    related_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    seen_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    accepted_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    rejected_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    title text NOT NULL,
    status text,
    priority text,
    category text,
    remind_type integer DEFAULT 0,
    remind_time interval,
    description text,
    comments text,
    percent_complete integer DEFAULT 0 NOT NULL,
    workflow_id integer,
    workflow_sequence_id integer,
    start_time date,
    due_time date
);


--
-- TOC entry 37 (OID 2396846)
-- Name: settings; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE settings (
    setting_key character varying(64) NOT NULL,
    value text NOT NULL,
    is_configurable integer DEFAULT 0 NOT NULL,
    treepos bit varying
);


\connect - postgres

--
-- TOC entry 126 (OID 2396853)
-- Name: bqarr_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION bqarr_in(cstring) RETURNS query_int
    AS '$libdir/_int', 'bqarr_in'
    LANGUAGE c STRICT;


--
-- TOC entry 127 (OID 2396854)
-- Name: bqarr_out(query_int); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION bqarr_out(query_int) RETURNS cstring
    AS '$libdir/_int', 'bqarr_out'
    LANGUAGE c STRICT;


--
-- TOC entry 4 (OID 2396852)
-- Name: query_int; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE query_int (
    INTERNALLENGTH = variable,
    INPUT = bqarr_in,
    OUTPUT = bqarr_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 128 (OID 2396856)
-- Name: querytree(query_int); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION querytree(query_int) RETURNS text
    AS '$libdir/_int', 'querytree'
    LANGUAGE c STRICT;


--
-- TOC entry 129 (OID 2396857)
-- Name: boolop(integer[], query_int); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION boolop(integer[], query_int) RETURNS boolean
    AS '$libdir/_int', 'boolop'
    LANGUAGE c STRICT;


--
-- TOC entry 130 (OID 2396858)
-- Name: rboolop(query_int, integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rboolop(query_int, integer[]) RETURNS boolean
    AS '$libdir/_int', 'rboolop'
    LANGUAGE c STRICT;


--
-- TOC entry 171 (OID 2396859)
-- Name: @@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @@ (
    PROCEDURE = boolop,
    LEFTARG = integer[],
    RIGHTARG = query_int,
    COMMUTATOR = ~~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 169 (OID 2396860)
-- Name: ~~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~~ (
    PROCEDURE = rboolop,
    LEFTARG = query_int,
    RIGHTARG = integer[],
    COMMUTATOR = @@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 131 (OID 2396861)
-- Name: _int_contains(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_contains(integer[], integer[]) RETURNS boolean
    AS '$libdir/_int', '_int_contains'
    LANGUAGE c STRICT;


--
-- TOC entry 132 (OID 2396862)
-- Name: _int_contained(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_contained(integer[], integer[]) RETURNS boolean
    AS '$libdir/_int', '_int_contained'
    LANGUAGE c STRICT;


--
-- TOC entry 133 (OID 2396863)
-- Name: _int_overlap(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_overlap(integer[], integer[]) RETURNS boolean
    AS '$libdir/_int', '_int_overlap'
    LANGUAGE c STRICT;


--
-- TOC entry 134 (OID 2396864)
-- Name: _int_same(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_same(integer[], integer[]) RETURNS boolean
    AS '$libdir/_int', '_int_same'
    LANGUAGE c STRICT;


--
-- TOC entry 135 (OID 2396865)
-- Name: _int_different(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_different(integer[], integer[]) RETURNS boolean
    AS '$libdir/_int', '_int_different'
    LANGUAGE c STRICT;


--
-- TOC entry 136 (OID 2396866)
-- Name: _int_union(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_union(integer[], integer[]) RETURNS integer[]
    AS '$libdir/_int', '_int_union'
    LANGUAGE c STRICT;


--
-- TOC entry 137 (OID 2396867)
-- Name: _int_inter(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _int_inter(integer[], integer[]) RETURNS integer[]
    AS '$libdir/_int', '_int_inter'
    LANGUAGE c STRICT;


--
-- TOC entry 173 (OID 2396868)
-- Name: &&; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR && (
    PROCEDURE = _int_overlap,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = &&,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 174 (OID 2396870)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = _int_different,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = <>,
    NEGATOR = =,
    RESTRICT = neqsel,
    JOIN = neqjoinsel
);


--
-- TOC entry 176 (OID 2396871)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = _int_contains,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 175 (OID 2396872)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = _int_contained,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 138 (OID 2396873)
-- Name: intset(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION intset(integer) RETURNS integer[]
    AS '$libdir/_int', 'intset'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 139 (OID 2396874)
-- Name: icount(integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION icount(integer[]) RETURNS integer
    AS '$libdir/_int', 'icount'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 177 (OID 2396875)
-- Name: #; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR # (
    PROCEDURE = icount,
    RIGHTARG = integer[]
);


--
-- TOC entry 140 (OID 2396876)
-- Name: sort(integer[], text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sort(integer[], text) RETURNS integer[]
    AS '$libdir/_int', 'sort'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 141 (OID 2396877)
-- Name: sort(integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sort(integer[]) RETURNS integer[]
    AS '$libdir/_int', 'sort'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 142 (OID 2396878)
-- Name: sort_asc(integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sort_asc(integer[]) RETURNS integer[]
    AS '$libdir/_int', 'sort_asc'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 143 (OID 2396879)
-- Name: sort_desc(integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sort_desc(integer[]) RETURNS integer[]
    AS '$libdir/_int', 'sort_desc'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 144 (OID 2396880)
-- Name: uniq(integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION uniq(integer[]) RETURNS integer[]
    AS '$libdir/_int', 'uniq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 145 (OID 2396881)
-- Name: idx(integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION idx(integer[], integer) RETURNS integer
    AS '$libdir/_int', 'idx'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 178 (OID 2396882)
-- Name: #; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR # (
    PROCEDURE = idx,
    LEFTARG = integer[],
    RIGHTARG = integer
);


--
-- TOC entry 146 (OID 2396883)
-- Name: subarray(integer[], integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subarray(integer[], integer, integer) RETURNS integer[]
    AS '$libdir/_int', 'subarray'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 147 (OID 2396884)
-- Name: subarray(integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subarray(integer[], integer) RETURNS integer[]
    AS '$libdir/_int', 'subarray'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 148 (OID 2396885)
-- Name: intarray_push_elem(integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION intarray_push_elem(integer[], integer) RETURNS integer[]
    AS '$libdir/_int', 'intarray_push_elem'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 179 (OID 2396886)
-- Name: +; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR + (
    PROCEDURE = intarray_push_elem,
    LEFTARG = integer[],
    RIGHTARG = integer
);


--
-- TOC entry 149 (OID 2396887)
-- Name: intarray_push_array(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION intarray_push_array(integer[], integer[]) RETURNS integer[]
    AS '$libdir/_int', 'intarray_push_array'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 180 (OID 2396888)
-- Name: +; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR + (
    PROCEDURE = intarray_push_array,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = +
);


--
-- TOC entry 150 (OID 2396889)
-- Name: intarray_del_elem(integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION intarray_del_elem(integer[], integer) RETURNS integer[]
    AS '$libdir/_int', 'intarray_del_elem'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 181 (OID 2396890)
-- Name: -; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR - (
    PROCEDURE = intarray_del_elem,
    LEFTARG = integer[],
    RIGHTARG = integer
);


--
-- TOC entry 151 (OID 2396891)
-- Name: intset_union_elem(integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION intset_union_elem(integer[], integer) RETURNS integer[]
    AS '$libdir/_int', 'intset_union_elem'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 182 (OID 2396892)
-- Name: |; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR | (
    PROCEDURE = intset_union_elem,
    LEFTARG = integer[],
    RIGHTARG = integer
);


--
-- TOC entry 168 (OID 2396893)
-- Name: |; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR | (
    PROCEDURE = _int_union,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = |
);


--
-- TOC entry 152 (OID 2396894)
-- Name: intset_subtract(integer[], integer[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION intset_subtract(integer[], integer[]) RETURNS integer[]
    AS '$libdir/_int', 'intset_subtract'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 170 (OID 2396895)
-- Name: -; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR - (
    PROCEDURE = intset_subtract,
    LEFTARG = integer[],
    RIGHTARG = integer[]
);


--
-- TOC entry 172 (OID 2396896)
-- Name: &; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR & (
    PROCEDURE = _int_inter,
    LEFTARG = integer[],
    RIGHTARG = integer[],
    COMMUTATOR = &
);


--
-- TOC entry 153 (OID 2396897)
-- Name: g_int_consistent(internal, integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_consistent(internal, integer[], integer) RETURNS boolean
    AS '$libdir/_int', 'g_int_consistent'
    LANGUAGE c;


--
-- TOC entry 154 (OID 2396898)
-- Name: g_int_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_compress(internal) RETURNS internal
    AS '$libdir/_int', 'g_int_compress'
    LANGUAGE c;


--
-- TOC entry 155 (OID 2396899)
-- Name: g_int_decompress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_decompress(internal) RETURNS internal
    AS '$libdir/_int', 'g_int_decompress'
    LANGUAGE c;


--
-- TOC entry 156 (OID 2396900)
-- Name: g_int_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/_int', 'g_int_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 157 (OID 2396901)
-- Name: g_int_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_picksplit(internal, internal) RETURNS internal
    AS '$libdir/_int', 'g_int_picksplit'
    LANGUAGE c;


--
-- TOC entry 158 (OID 2396902)
-- Name: g_int_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_union(bytea, internal) RETURNS integer[]
    AS '$libdir/_int', 'g_int_union'
    LANGUAGE c;


--
-- TOC entry 159 (OID 2396903)
-- Name: g_int_same(integer[], integer[], internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_int_same(integer[], integer[], internal) RETURNS internal
    AS '$libdir/_int', 'g_int_same'
    LANGUAGE c;


--
-- TOC entry 183 (OID 2396904)
-- Name: gist__int_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist__int_ops
    DEFAULT FOR TYPE integer[] USING gist AS
    OPERATOR 3 &&(integer[],integer[]) ,
    OPERATOR 6 =(integer[],integer[]) RECHECK ,
    OPERATOR 7 @(integer[],integer[]) ,
    OPERATOR 8 ~(integer[],integer[]) ,
    OPERATOR 20 @@(integer[],query_int) ,
    FUNCTION 1 g_int_consistent(internal,integer[],integer) ,
    FUNCTION 2 g_int_union(bytea,internal) ,
    FUNCTION 3 g_int_compress(internal) ,
    FUNCTION 4 g_int_decompress(internal) ,
    FUNCTION 5 g_int_penalty(internal,internal,internal) ,
    FUNCTION 6 g_int_picksplit(internal,internal) ,
    FUNCTION 7 g_int_same(integer[],integer[],internal);


--
-- TOC entry 160 (OID 2396905)
-- Name: g_intbig_consistent(internal, integer[], integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_consistent(internal, integer[], integer) RETURNS boolean
    AS '$libdir/_int', 'g_intbig_consistent'
    LANGUAGE c;


--
-- TOC entry 161 (OID 2396906)
-- Name: g_intbig_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_compress(internal) RETURNS internal
    AS '$libdir/_int', 'g_intbig_compress'
    LANGUAGE c;


--
-- TOC entry 162 (OID 2396907)
-- Name: g_intbig_decompress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_decompress(internal) RETURNS internal
    AS '$libdir/_int', 'g_intbig_decompress'
    LANGUAGE c;


--
-- TOC entry 163 (OID 2396908)
-- Name: g_intbig_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/_int', 'g_intbig_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 164 (OID 2396909)
-- Name: g_intbig_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_picksplit(internal, internal) RETURNS internal
    AS '$libdir/_int', 'g_intbig_picksplit'
    LANGUAGE c;


--
-- TOC entry 165 (OID 2396910)
-- Name: g_intbig_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_union(bytea, internal) RETURNS integer[]
    AS '$libdir/_int', 'g_intbig_union'
    LANGUAGE c;


--
-- TOC entry 166 (OID 2396911)
-- Name: g_intbig_same(integer[], integer[], internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION g_intbig_same(integer[], integer[], internal) RETURNS internal
    AS '$libdir/_int', 'g_intbig_same'
    LANGUAGE c;


--
-- TOC entry 184 (OID 2396912)
-- Name: gist__intbig_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist__intbig_ops
    FOR TYPE integer[] USING gist AS
    OPERATOR 3 &&(integer[],integer[]) RECHECK ,
    OPERATOR 6 =(integer[],integer[]) RECHECK ,
    OPERATOR 7 @(integer[],integer[]) RECHECK ,
    OPERATOR 8 ~(integer[],integer[]) RECHECK ,
    OPERATOR 20 @@(integer[],query_int) RECHECK ,
    FUNCTION 1 g_intbig_consistent(internal,integer[],integer) ,
    FUNCTION 2 g_intbig_union(bytea,internal) ,
    FUNCTION 3 g_intbig_compress(internal) ,
    FUNCTION 4 g_intbig_decompress(internal) ,
    FUNCTION 5 g_intbig_penalty(internal,internal,internal) ,
    FUNCTION 6 g_intbig_picksplit(internal,internal) ,
    FUNCTION 7 g_intbig_same(integer[],integer[],internal);


\connect - conflux

--
-- TOC entry 38 (OID 2396913)
-- Name: emails_received; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE emails_received (
    email_account text,
    email_message_id text,
    email_pop3_uid text,
    parent_id integer NOT NULL
);


--
-- TOC entry 39 (OID 2396918)
-- Name: usernotes; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE usernotes (
    note_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    note_message text NOT NULL,
    note_color integer DEFAULT 0 NOT NULL
);


--
-- TOC entry 40 (OID 2396924)
-- Name: disccategories; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE disccategories (
    disccategory_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    disccategory_name text NOT NULL
);


--
-- TOC entry 15 (OID 2396930)
-- Name: systemnote_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE systemnote_seq;


--
-- TOC entry 41 (OID 2396932)
-- Name: systemnotes; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE systemnotes (
    note_id integer DEFAULT nextval('systemnote_seq'::text) NOT NULL,
    note_message text NOT NULL,
    note_stamp date DEFAULT now()
);


--
-- TOC entry 42 (OID 2396939)
-- Name: discussions; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE discussions (
    discussion_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    disc_subject text NOT NULL,
    disc_message text,
    is_front_page boolean DEFAULT false NOT NULL
);


--
-- TOC entry 43 (OID 2396946)
-- Name: resources; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE resources (
    resource_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    resource_name text NOT NULL
);


--
-- TOC entry 44 (OID 2396952)
-- Name: event_resources; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE event_resources (
    event_id integer,
    resource_id integer
);


--
-- TOC entry 45 (OID 2396954)
-- Name: item_rels; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE item_rels (
    left_item_id integer,
    right_item_id integer
);


--
-- TOC entry 46 (OID 2396956)
-- Name: bookmarks; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE bookmarks (
    bookmark_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    bookmark_url text NOT NULL,
    bookmark_description text,
    is_category integer
);


--
-- TOC entry 47 (OID 2396962)
-- Name: workflows; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE workflows (
    workflow_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    workflow_title text NOT NULL,
    workflow_description text,
    workflow_flags integer DEFAULT 0 NOT NULL,
    related_persons integer[] DEFAULT '{}'::integer[] NOT NULL,
    percent_complete integer DEFAULT 0 NOT NULL,
    workflow_start_time date,
    workflow_due_time date
);


--
-- TOC entry 48 (OID 2396971)
-- Name: calendar_groups; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE calendar_groups (
    parent_id integer NOT NULL,
    group_name text NOT NULL,
    members integer[] DEFAULT '{}'::integer[] NOT NULL,
    group_id integer DEFAULT nextval('calendar_groups_seq'::text) NOT NULL
);


--
-- TOC entry 17 (OID 2396978)
-- Name: calendar_groups_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE calendar_groups_seq;


--
-- TOC entry 49 (OID 2396980)
-- Name: email_filters; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE email_filters (
    filter_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    condition_id integer NOT NULL,
    keywords text NOT NULL,
    action_id integer NOT NULL,
    folder_id integer NOT NULL,
    use_case boolean DEFAULT false NOT NULL,
    priority integer DEFAULT 1 NOT NULL
);


--
-- TOC entry 167 (OID 2396988)
-- Name: items_treepos_trig(); Type: FUNCTION; Schema: public; Owner: conflux
--

CREATE FUNCTION items_treepos_trig() RETURNS "trigger"
    AS '
  DECLARE
    parent_rec RECORD;
  BEGIN
    SELECT INTO parent_rec treepos FROM items WHERE item_id = NEW.parent_id;
    NEW.treepos := parent_rec.treepos || "bit"(NEW.item_id);
    RETURN NEW;
  END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 50 (OID 2427177)
-- Name: clients; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE clients (
    client_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    client_name text NOT NULL,
    client_nr text,
    telephone text,
    fax text,
    e_mail text,
    registry_code text,
    client_type text,
    client_field text,
    client_rating integer,
    client_ownership text,
    homepage text,
    vat_nr text,
    country text,
    mail_address text,
    legal_address text,
    description text,
    bank_reqs text
);


--
-- TOC entry 51 (OID 2427382)
-- Name: opportunities; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE opportunities (
    opp_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    opp_name text NOT NULL,
    client_id integer NOT NULL,
    opp_stage integer NOT NULL,
    opp_next_stage text,
    description text,
    req_descr text,
    amount numeric(10,2),
    close_date date NOT NULL,
    opp_lost text,
    lead_source text,
    client_type text
);


--
-- TOC entry 52 (OID 2428742)
-- Name: products; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE products (
    product_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    product_name text NOT NULL,
    product_group text,
    product_unit text,
    product_price numeric(10,2),
    description text
);


--
-- TOC entry 53 (OID 2428755)
-- Name: opp_products; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE opp_products (
    opp_id integer NOT NULL,
    product_id integer NOT NULL,
    amount numeric(10,2),
    price numeric(10,2),
    key_requirement text
);


--
-- TOC entry 54 (OID 2434140)
-- Name: fti_search; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE fti_search (
    word text NOT NULL,
    item_id integer NOT NULL,
    fti_type boolean DEFAULT false NOT NULL
);


--
-- TOC entry 19 (OID 2434766)
-- Name: log_batch_seq; Type: SEQUENCE; Schema: public; Owner: conflux
--

CREATE SEQUENCE log_batch_seq;


--
-- TOC entry 55 (OID 2434768)
-- Name: item_log; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE item_log (
    item_id integer NOT NULL,
    batch_id integer NOT NULL,
    person_id integer NOT NULL,
    change_time timestamp with time zone DEFAULT now() NOT NULL,
    field_name text NOT NULL,
    old_value text NOT NULL,
    new_value text NOT NULL,
    log_flags integer DEFAULT 0 NOT NULL
);


--
-- TOC entry 56 (OID 2446042)
-- Name: items_scrollback; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE items_scrollback (
    item_id integer NOT NULL,
    parent_id integer NOT NULL,
    item_name text NOT NULL,
    item_type_id integer NOT NULL,
    deleter_id integer NOT NULL,
    delete_time timestamp with time zone DEFAULT now() NOT NULL,
    conflux_tid integer NOT NULL,
    scrollback_flags integer DEFAULT 0 NOT NULL
);


--
-- TOC entry 57 (OID 2453726)
-- Name: quotas; Type: TABLE; Schema: public; Owner: conflux
--

CREATE TABLE quotas (
    quota_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    quota_soft_size integer NOT NULL,
    quota_hard_size integer NOT NULL,
    quota_used bigint DEFAULT 0 NOT NULL
);


--
-- Data for TOC entry 185 (OID 2396709)
-- Name: access_rights; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY access_rights (item_id, group_id, right_id, treepos) FROM stdin;
\.


--
-- Data for TOC entry 186 (OID 2396714)
-- Name: access_groups; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY access_groups (group_id, person_id) FROM stdin;
\.


--
-- Data for TOC entry 187 (OID 2396716)
-- Name: items; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY items (item_id, parent_id, item_name, item_size, creator_id, creator_ip, create_time, editor_id, editor_ip, edit_time, item_type_id, is_internal, is_public, is_private, treepos, owner_id, index_this_item) FROM stdin;
0	0	Root Organization	0	0	127.0.0.1	2003-04-15 03:31:30.587225+03	0	127.0.0.1	2003-04-15 03:31:30.587225+03	2	f	f	f	00000000000000000000000000000000	\N	\N
1	3	System Administrator	0	0	127.0.0.1	2003-04-15 03:31:30.587225+03	1	192.168.0.188	2004-08-03 21:24:22.384631+03	1	f	f	f	000000000000000000000000000000000000000000000000000000000000001100000000000000000000000000000001	\N	0
3	0	System organization	0	0	127.0.0.1	2003-04-15 03:31:30.587225+03	1	192.168.0.104	2004-07-31 18:54:56.706526+03	2	f	f	f	0000000000000000000000000000000000000000000000000000000000000011	\N	0
\.


--
-- Data for TOC entry 188 (OID 2396748)
-- Name: item_types; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY item_types (item_type_id, item_type_name, item_type_icon) FROM stdin;
1	Persons	person.gif
2	Organizations	toporg.gif
3	Folders	fld.gif
4	Documents	document.gif
5	Events	event.gif
6	Todos	todo.gif
7	Contacts	contact.gif
8	eFolders	efolder.gif
9	e-mails	email.gif
10	eAccounts	eaccount.gif
11	Discussions	discussion.gif
12	UserNotes	usernote.gif
13	Discussion categories	disccategory.gif
14	Calendar resources	resource.gif
15	Bookmarks	bookmark.gif
16	Workflows	workflow.gif
17	E-filter	efilter.gif
18	Client	client.gif
19	Opportunity	opportunity.gif
20	Product	product.gif
21	Quota	quota.gif
23	Contact groups	ontactgroups.gif
\.


--
-- Data for TOC entry 189 (OID 2396751)
-- Name: sessions; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY sessions (session_id, session_key, user_id, user_ip, start_stamp, update_stamp, update_count) FROM stdin;
\.


--
-- Data for TOC entry 190 (OID 2396759)
-- Name: persons; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY persons (person_id, first_name, middle_name, last_name, username, "password", phone_work, phone_home, phone_cell, phone_fax, e_mail, is_disabled, picture, email_notify, is_deleted) FROM stdin;
1	System		Administrator	superuser	Xa1ZzylkmZzmk						0		0	0
\.


--
-- Data for TOC entry 191 (OID 2396766)
-- Name: contacts; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY contacts (contact_id, first_name, middle_name, last_name, company, department, jobtitle, phone_work, phone_home, phone_cell, phone_fax, e_mail, mailing_address, description, homepage, contact_category, birth_date, contact_sex) FROM stdin;
\.


--
-- Data for TOC entry 192 (OID 2396773)
-- Name: organizations; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY organizations (organization_id, organization_name, address, city, state, zipcode, country, website, email, telephone, fax, superuser_id) FROM stdin;
0	Root organization	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3	System organization										\N
\.


--
-- Data for TOC entry 193 (OID 2396779)
-- Name: user_groups; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY user_groups (group_id, group_org_id, group_name, top_org_id) FROM stdin;
1	3	Default group	\N
\.


--
-- Data for TOC entry 194 (OID 2396787)
-- Name: events; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY events (event_id, event_name, event_priority, event_activity, start_stamp, end_stamp, description, comments, remind_type, remind_time, related_persons, seen_persons, accepted_persons, rejected_persons, repeat_interval, dayofweek, dayofmonth, monthofyear, repeat_type, last_reminder, related_groups, event_flags) FROM stdin;
\.


--
-- Data for TOC entry 195 (OID 2396800)
-- Name: emails; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY emails (email_id, email_from, email_subject, email_to, email_date, email_savedate, email_size, email_flags, email_message_id, email_contents, email_contacts, email_from_addr) FROM stdin;
\.


--
-- Data for TOC entry 196 (OID 2396808)
-- Name: efolders; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY efolders (efolder_id, efolder_name, efolder_flags) FROM stdin;
\.


--
-- Data for TOC entry 197 (OID 2396814)
-- Name: eaccounts; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY eaccounts (eaccount_id, eaccount_name, eaccount_user, eaccount_password, eaccount_flags) FROM stdin;
\.


--
-- Data for TOC entry 198 (OID 2396820)
-- Name: folders; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY folders (folder_id, folder_name, comments) FROM stdin;
\.


--
-- Data for TOC entry 199 (OID 2396826)
-- Name: documents; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY documents (document_id, filename, title, description, comments, author, mime_major, mime_minor, final_version_id, doc_category, locker_id, lock_due) FROM stdin;
\.


--
-- Data for TOC entry 200 (OID 2396834)
-- Name: todos; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY todos (todo_id, related_persons, seen_persons, accepted_persons, rejected_persons, title, status, priority, category, remind_type, remind_time, description, comments, percent_complete, workflow_id, workflow_sequence_id, start_time, due_time) FROM stdin;
\.


--
-- Data for TOC entry 201 (OID 2396846)
-- Name: settings; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY settings (setting_key, value, is_configurable, treepos) FROM stdin;
todo_statuses	KGxwMQpTJ05vdCBzdGFydGVkJwphUydTdGFydGVkJwpwMgphUydEb25lJwpwMwphUydOb3QgRG9u\nZScKYVMnQ291bGQgbm90IGRvJwphLg==\n	1	\N
cal_priorities	KGxwMQpTJ1RyaXZpYWwnCnAyCmFTJ05vcm1hbCcKcDMKYVMnSW1wb3J0YW50JwpwNAphUydDcml0\naWNhbCcKcDUKYS4=\n	1	\N
user_language	Uydlbl9VUycKcDAKLg==\n	1	\N
todo_priorities	KGxwMQpWSXJyZWxldmFudAphVk5vcm1hbAphVkltcG9ydGFudAphVkNyaXRpY2FsCmEu\n	1	\N
user_dateformat	VmVuX1VTCnAxCi4=\n	1	\N
todo_categories	KGxwMQpWV29yayByZWxhdGVkCmFWUGVyc29uYWwKYS4=\n	1	\N
contact_categories	KGxwMQpWQnVzaW5lc3MKYVZQZXJzb25hbAphVk90aGVyCmEu\n	1	\N
user_timezone	VjI3OjEzCnAxCi4==\n	1	\N
doc_categories	KGxwMQpWQ29udHJhY3QKcDIKYVZEb2N1bWVudApwMwphVkZpbGUKcDQKYVZNZW1vCnA1CmFWUHJv\ndG9jb2wKcDYKYVZSZXBvcnQKcDcKYS4=\n	1	\N
dictionary_languages	KGxwMQpWZW5fVVMKcDIKYVZldF9FRQpwMwphLg==\n	1	\N
\.


--
-- Data for TOC entry 202 (OID 2396913)
-- Name: emails_received; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY emails_received (email_account, email_message_id, email_pop3_uid, parent_id) FROM stdin;
\.


--
-- Data for TOC entry 203 (OID 2396918)
-- Name: usernotes; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY usernotes (note_id, note_message, note_color) FROM stdin;
\.


--
-- Data for TOC entry 204 (OID 2396924)
-- Name: disccategories; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY disccategories (disccategory_id, disccategory_name) FROM stdin;
\.


--
-- Data for TOC entry 205 (OID 2396932)
-- Name: systemnotes; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY systemnotes (note_id, note_message, note_stamp) FROM stdin;
\.


--
-- Data for TOC entry 206 (OID 2396939)
-- Name: discussions; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY discussions (discussion_id, disc_subject, disc_message, is_front_page) FROM stdin;
\.


--
-- Data for TOC entry 207 (OID 2396946)
-- Name: resources; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY resources (resource_id, resource_name) FROM stdin;
\.


--
-- Data for TOC entry 208 (OID 2396952)
-- Name: event_resources; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY event_resources (event_id, resource_id) FROM stdin;
\.


--
-- Data for TOC entry 209 (OID 2396954)
-- Name: item_rels; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY item_rels (left_item_id, right_item_id) FROM stdin;
\.


--
-- Data for TOC entry 210 (OID 2396956)
-- Name: bookmarks; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY bookmarks (bookmark_id, bookmark_url, bookmark_description, is_category) FROM stdin;
\.


--
-- Data for TOC entry 211 (OID 2396962)
-- Name: workflows; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY workflows (workflow_id, workflow_title, workflow_description, workflow_flags, related_persons, percent_complete, workflow_start_time, workflow_due_time) FROM stdin;
\.


--
-- Data for TOC entry 212 (OID 2396971)
-- Name: calendar_groups; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY calendar_groups (parent_id, group_name, members, group_id) FROM stdin;
\.


--
-- Data for TOC entry 213 (OID 2396980)
-- Name: email_filters; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY email_filters (filter_id, condition_id, keywords, action_id, folder_id, use_case, priority) FROM stdin;
\.


--
-- Data for TOC entry 214 (OID 2427177)
-- Name: clients; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY clients (client_id, client_name, client_nr, telephone, fax, e_mail, registry_code, client_type, client_field, client_rating, client_ownership, homepage, vat_nr, country, mail_address, legal_address, description, bank_reqs) FROM stdin;
\.


--
-- Data for TOC entry 215 (OID 2427382)
-- Name: opportunities; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY opportunities (opp_id, opp_name, client_id, opp_stage, opp_next_stage, description, req_descr, amount, close_date, opp_lost, lead_source, client_type) FROM stdin;
\.


--
-- Data for TOC entry 216 (OID 2428742)
-- Name: products; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY products (product_id, product_name, product_group, product_unit, product_price, description) FROM stdin;
\.


--
-- Data for TOC entry 217 (OID 2428755)
-- Name: opp_products; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY opp_products (opp_id, product_id, amount, price, key_requirement) FROM stdin;
\.


--
-- Data for TOC entry 218 (OID 2434140)
-- Name: fti_search; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY fti_search (word, item_id, fti_type) FROM stdin;
\.


--
-- Data for TOC entry 219 (OID 2434768)
-- Name: item_log; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY item_log (item_id, batch_id, person_id, change_time, field_name, old_value, new_value, log_flags) FROM stdin;
\.


--
-- Data for TOC entry 220 (OID 2446042)
-- Name: items_scrollback; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY items_scrollback (item_id, parent_id, item_name, item_type_id, deleter_id, delete_time, conflux_tid, scrollback_flags) FROM stdin;
\.


--
-- Data for TOC entry 221 (OID 2453726)
-- Name: quotas; Type: TABLE DATA; Schema: public; Owner: conflux
--

COPY quotas (quota_id, quota_soft_size, quota_hard_size, quota_used) FROM stdin;
\.


--
-- TOC entry 59 (OID 2403061)
-- Name: access_rights_itemid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX access_rights_itemid_ndx ON access_rights USING btree (item_id);


--
-- TOC entry 74 (OID 2403062)
-- Name: session_userid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX session_userid_ndx ON sessions USING btree (user_id);


--
-- TOC entry 75 (OID 2403063)
-- Name: session_userip_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX session_userip_ndx ON sessions USING btree (user_ip);


--
-- TOC entry 73 (OID 2403064)
-- Name: session_sessionkey_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX session_sessionkey_ndx ON sessions USING btree (session_key);


--
-- TOC entry 87 (OID 2403065)
-- Name: events_start_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX events_start_ndx ON events USING btree (start_stamp);


--
-- TOC entry 84 (OID 2403066)
-- Name: events_end_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX events_end_ndx ON events USING btree (end_stamp);


--
-- TOC entry 58 (OID 2403067)
-- Name: access_rights_groupid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX access_rights_groupid_ndx ON access_rights USING btree (group_id);


--
-- TOC entry 60 (OID 2403068)
-- Name: access_rights_rightid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX access_rights_rightid_ndx ON access_rights USING btree (right_id);


--
-- TOC entry 63 (OID 2403069)
-- Name: access_groups_personid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX access_groups_personid_ndx ON access_groups USING btree (person_id);


--
-- TOC entry 62 (OID 2403070)
-- Name: access_groups_groupid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX access_groups_groupid_ndx ON access_groups USING btree (group_id);


--
-- TOC entry 68 (OID 2403071)
-- Name: items_name_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX items_name_ndx ON items USING btree (item_name);


--
-- TOC entry 67 (OID 2403072)
-- Name: items_itemtypeid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX items_itemtypeid_ndx ON items USING btree (item_type_id);


--
-- TOC entry 82 (OID 2403073)
-- Name: usergroups_grouporgid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX usergroups_grouporgid_ndx ON user_groups USING btree (group_org_id);


--
-- TOC entry 95 (OID 2403076)
-- Name: todos_related_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX todos_related_ndx ON todos USING gist (related_persons);


--
-- TOC entry 86 (OID 2403077)
-- Name: events_related_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX events_related_ndx ON events USING gist (related_persons);


--
-- TOC entry 64 (OID 2403078)
-- Name: items_creatorid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX items_creatorid_ndx ON items USING btree (creator_id);


--
-- TOC entry 69 (OID 2403079)
-- Name: items_parentid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX items_parentid_ndx ON items USING btree (parent_id);


--
-- TOC entry 65 (OID 2403080)
-- Name: items_isprivate_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX items_isprivate_ndx ON items USING btree (is_private);


--
-- TOC entry 66 (OID 2403081)
-- Name: items_ispublic_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX items_ispublic_ndx ON items USING btree (is_public);


--
-- TOC entry 102 (OID 2403085)
-- Name: evnt_res_ev_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX evnt_res_ev_ndx ON event_resources USING btree (event_id);


--
-- TOC entry 103 (OID 2403086)
-- Name: evnt_res_res_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX evnt_res_res_ndx ON event_resources USING btree (resource_id);


--
-- TOC entry 104 (OID 2403087)
-- Name: item_rels_left; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX item_rels_left ON item_rels USING btree (left_item_id);


--
-- TOC entry 105 (OID 2403088)
-- Name: item_rels_right; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX item_rels_right ON item_rels USING btree (right_item_id);


--
-- TOC entry 108 (OID 2403090)
-- Name: cal_groups_uniq; Type: INDEX; Schema: public; Owner: conflux
--

CREATE UNIQUE INDEX cal_groups_uniq ON calendar_groups USING btree (parent_id, group_name);


--
-- TOC entry 71 (OID 2403091)
-- Name: items_treepos_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE UNIQUE INDEX items_treepos_ndx ON items USING btree (treepos);


--
-- TOC entry 96 (OID 2403092)
-- Name: settings_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE UNIQUE INDEX settings_ndx ON settings USING btree (setting_key, treepos);


--
-- TOC entry 61 (OID 2417778)
-- Name: access_rights_treepos_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX access_rights_treepos_ndx ON access_rights USING btree (treepos);


--
-- TOC entry 111 (OID 2427394)
-- Name: opp_client_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX opp_client_ndx ON opportunities USING btree (client_id);


--
-- TOC entry 83 (OID 2428355)
-- Name: usergroups_toporgid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX usergroups_toporgid_ndx ON user_groups USING btree (top_org_id);


--
-- TOC entry 114 (OID 2428768)
-- Name: opp_product_opp_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX opp_product_opp_ndx ON opp_products USING btree (opp_id);


--
-- TOC entry 115 (OID 2428769)
-- Name: opp_product_prod_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX opp_product_prod_ndx ON opp_products USING btree (product_id);


--
-- TOC entry 116 (OID 2434146)
-- Name: fti_item_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX fti_item_ndx ON fti_search USING btree (item_id, fti_type);


--
-- TOC entry 117 (OID 2434147)
-- Name: fti_word_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX fti_word_ndx ON fti_search USING btree (word, fti_type);


--
-- TOC entry 119 (OID 2434782)
-- Name: item_log_item_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX item_log_item_ndx ON item_log USING btree (item_id);


--
-- TOC entry 120 (OID 2434783)
-- Name: item_log_person_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX item_log_person_ndx ON item_log USING btree (person_id);


--
-- TOC entry 118 (OID 2434784)
-- Name: item_log_field_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX item_log_field_ndx ON item_log USING btree (field_name);


--
-- TOC entry 88 (OID 2439075)
-- Name: emails_addr_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX emails_addr_ndx ON emails USING btree (email_from_addr);


--
-- TOC entry 122 (OID 2446048)
-- Name: scrollback_itemid_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE UNIQUE INDEX scrollback_itemid_ndx ON items_scrollback USING btree (conflux_tid, item_id);


--
-- TOC entry 121 (OID 2446693)
-- Name: scrollback_item_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX scrollback_item_ndx ON items_scrollback USING btree (item_id);


--
-- TOC entry 77 (OID 2822953)
-- Name: persons_deleted_ndx; Type: INDEX; Schema: public; Owner: conflux
--

CREATE INDEX persons_deleted_ndx ON persons USING btree (is_deleted);


--
-- TOC entry 70 (OID 2403093)
-- Name: items_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY items
    ADD CONSTRAINT items_pkey PRIMARY KEY (item_id);


--
-- TOC entry 85 (OID 2403095)
-- Name: events_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY events
    ADD CONSTRAINT events_pkey PRIMARY KEY (event_id);


--
-- TOC entry 93 (OID 2403097)
-- Name: documents_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY documents
    ADD CONSTRAINT documents_pkey PRIMARY KEY (document_id);


--
-- TOC entry 89 (OID 2403099)
-- Name: emails_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY emails
    ADD CONSTRAINT emails_pkey PRIMARY KEY (email_id);


--
-- TOC entry 90 (OID 2403101)
-- Name: efolders_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY efolders
    ADD CONSTRAINT efolders_pkey PRIMARY KEY (efolder_id);


--
-- TOC entry 91 (OID 2403103)
-- Name: eaccounts_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY eaccounts
    ADD CONSTRAINT eaccounts_pkey PRIMARY KEY (eaccount_id);


--
-- TOC entry 92 (OID 2403105)
-- Name: folders_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY folders
    ADD CONSTRAINT folders_pkey PRIMARY KEY (folder_id);


--
-- TOC entry 94 (OID 2403107)
-- Name: todos_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY todos
    ADD CONSTRAINT todos_pkey PRIMARY KEY (todo_id);


--
-- TOC entry 72 (OID 2403109)
-- Name: item_types_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY item_types
    ADD CONSTRAINT item_types_pkey PRIMARY KEY (item_type_id);


--
-- TOC entry 76 (OID 2403111)
-- Name: sessions_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY sessions
    ADD CONSTRAINT sessions_pkey PRIMARY KEY (session_id);


--
-- TOC entry 78 (OID 2403113)
-- Name: persons_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY persons
    ADD CONSTRAINT persons_pkey PRIMARY KEY (person_id);


--
-- TOC entry 79 (OID 2403115)
-- Name: contacts_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY contacts
    ADD CONSTRAINT contacts_pkey PRIMARY KEY (contact_id);


--
-- TOC entry 80 (OID 2403117)
-- Name: organizations_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY organizations
    ADD CONSTRAINT organizations_pkey PRIMARY KEY (organization_id);


--
-- TOC entry 81 (OID 2403119)
-- Name: user_groups_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY user_groups
    ADD CONSTRAINT user_groups_pkey PRIMARY KEY (group_id);


--
-- TOC entry 97 (OID 2403121)
-- Name: usernotes_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY usernotes
    ADD CONSTRAINT usernotes_pkey PRIMARY KEY (note_id);


--
-- TOC entry 98 (OID 2403123)
-- Name: disccategories_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY disccategories
    ADD CONSTRAINT disccategories_pkey PRIMARY KEY (disccategory_id);


--
-- TOC entry 99 (OID 2403125)
-- Name: systemnotes_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY systemnotes
    ADD CONSTRAINT systemnotes_pkey PRIMARY KEY (note_id);


--
-- TOC entry 100 (OID 2403127)
-- Name: discussions_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY discussions
    ADD CONSTRAINT discussions_pkey PRIMARY KEY (discussion_id);


--
-- TOC entry 101 (OID 2403129)
-- Name: resources_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY resources
    ADD CONSTRAINT resources_pkey PRIMARY KEY (resource_id);


--
-- TOC entry 106 (OID 2403131)
-- Name: bookmarks_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY bookmarks
    ADD CONSTRAINT bookmarks_pkey PRIMARY KEY (bookmark_id);


--
-- TOC entry 107 (OID 2403133)
-- Name: workflows_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY workflows
    ADD CONSTRAINT workflows_pkey PRIMARY KEY (workflow_id);


--
-- TOC entry 109 (OID 2403135)
-- Name: email_filters_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY email_filters
    ADD CONSTRAINT email_filters_pkey PRIMARY KEY (filter_id);


--
-- TOC entry 110 (OID 2427183)
-- Name: clients_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY clients
    ADD CONSTRAINT clients_pkey PRIMARY KEY (client_id);


--
-- TOC entry 112 (OID 2427388)
-- Name: opportunities_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY opportunities
    ADD CONSTRAINT opportunities_pkey PRIMARY KEY (opp_id);


--
-- TOC entry 113 (OID 2428749)
-- Name: products_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY products
    ADD CONSTRAINT products_pkey PRIMARY KEY (product_id);


--
-- TOC entry 123 (OID 2453730)
-- Name: quotas_pkey; Type: CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY quotas
    ADD CONSTRAINT quotas_pkey PRIMARY KEY (quota_id);


--
-- TOC entry 233 (OID 2403137)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY events
    ADD CONSTRAINT "$1" FOREIGN KEY (event_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 239 (OID 2403141)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY todos
    ADD CONSTRAINT "$1" FOREIGN KEY (todo_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 229 (OID 2403145)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY contacts
    ADD CONSTRAINT "$1" FOREIGN KEY (contact_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 236 (OID 2403149)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY eaccounts
    ADD CONSTRAINT "$1" FOREIGN KEY (eaccount_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 235 (OID 2403153)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY efolders
    ADD CONSTRAINT "$1" FOREIGN KEY (efolder_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 234 (OID 2403157)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY emails
    ADD CONSTRAINT "$1" FOREIGN KEY (email_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 241 (OID 2403161)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY emails_received
    ADD CONSTRAINT "$1" FOREIGN KEY (parent_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 230 (OID 2403165)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY organizations
    ADD CONSTRAINT "$1" FOREIGN KEY (organization_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 228 (OID 2403169)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY persons
    ADD CONSTRAINT "$1" FOREIGN KEY (person_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 231 (OID 2403173)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY user_groups
    ADD CONSTRAINT "$1" FOREIGN KEY (group_org_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 222 (OID 2403177)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY access_rights
    ADD CONSTRAINT "$1" FOREIGN KEY (item_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 223 (OID 2403181)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY access_rights
    ADD CONSTRAINT "$2" FOREIGN KEY (group_id) REFERENCES user_groups(group_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 225 (OID 2403185)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY access_groups
    ADD CONSTRAINT "$1" FOREIGN KEY (group_id) REFERENCES user_groups(group_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 226 (OID 2403189)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY access_groups
    ADD CONSTRAINT "$2" FOREIGN KEY (person_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 238 (OID 2403193)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY documents
    ADD CONSTRAINT "$1" FOREIGN KEY (document_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 237 (OID 2403197)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY folders
    ADD CONSTRAINT "$1" FOREIGN KEY (folder_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 227 (OID 2403201)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY sessions
    ADD CONSTRAINT "$1" FOREIGN KEY (user_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 242 (OID 2403205)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY usernotes
    ADD CONSTRAINT "$1" FOREIGN KEY (note_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 243 (OID 2403209)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY disccategories
    ADD CONSTRAINT "$1" FOREIGN KEY (disccategory_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 244 (OID 2403213)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY discussions
    ADD CONSTRAINT "$1" FOREIGN KEY (discussion_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 245 (OID 2403217)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY resources
    ADD CONSTRAINT "$1" FOREIGN KEY (resource_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 246 (OID 2403221)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY event_resources
    ADD CONSTRAINT "$1" FOREIGN KEY (event_id) REFERENCES events(event_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 247 (OID 2403225)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY event_resources
    ADD CONSTRAINT "$2" FOREIGN KEY (resource_id) REFERENCES resources(resource_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 248 (OID 2403229)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY item_rels
    ADD CONSTRAINT "$1" FOREIGN KEY (left_item_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 249 (OID 2403233)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY item_rels
    ADD CONSTRAINT "$2" FOREIGN KEY (right_item_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 250 (OID 2403237)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY bookmarks
    ADD CONSTRAINT "$1" FOREIGN KEY (bookmark_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 251 (OID 2403241)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY workflows
    ADD CONSTRAINT "$1" FOREIGN KEY (workflow_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 252 (OID 2403245)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY email_filters
    ADD CONSTRAINT "$1" FOREIGN KEY (filter_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 240 (OID 2403253)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY settings
    ADD CONSTRAINT "$1" FOREIGN KEY (treepos) REFERENCES items(treepos) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 253 (OID 2427185)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY clients
    ADD CONSTRAINT "$1" FOREIGN KEY (client_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 254 (OID 2427390)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY opportunities
    ADD CONSTRAINT "$1" FOREIGN KEY (opp_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 255 (OID 2427395)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY opportunities
    ADD CONSTRAINT "$2" FOREIGN KEY (client_id) REFERENCES clients(client_id) ON UPDATE RESTRICT ON DELETE RESTRICT;


--
-- TOC entry 232 (OID 2428356)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY user_groups
    ADD CONSTRAINT "$2" FOREIGN KEY (top_org_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 256 (OID 2428751)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY products
    ADD CONSTRAINT "$1" FOREIGN KEY (product_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 257 (OID 2428760)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY opp_products
    ADD CONSTRAINT "$1" FOREIGN KEY (opp_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 258 (OID 2428764)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY opp_products
    ADD CONSTRAINT "$2" FOREIGN KEY (product_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 224 (OID 2435546)
-- Name: $3; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY access_rights
    ADD CONSTRAINT "$3" FOREIGN KEY (treepos) REFERENCES items(treepos) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 259 (OID 2453732)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: conflux
--

ALTER TABLE ONLY quotas
    ADD CONSTRAINT "$1" FOREIGN KEY (quota_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


--
-- TOC entry 260 (OID 2403257)
-- Name: items_treepos_trig; Type: TRIGGER; Schema: public; Owner: conflux
--

CREATE TRIGGER items_treepos_trig
    BEFORE INSERT OR UPDATE ON items
    FOR EACH ROW
    EXECUTE PROCEDURE items_treepos_trig();


--
-- TOC entry 6 (OID 2396705)
-- Name: item_id_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('item_id_seq', 13134, true);


--
-- TOC entry 8 (OID 2396707)
-- Name: scrollback_id_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('scrollback_id_seq', 1534, true);


--
-- TOC entry 10 (OID 2396746)
-- Name: item_type_id_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('item_type_id_seq', 19, true);


--
-- TOC entry 12 (OID 2396757)
-- Name: session_id_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('session_id_seq', 509, true);


--
-- TOC entry 14 (OID 2396785)
-- Name: user_groups_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('user_groups_seq', 45, true);


--
-- TOC entry 16 (OID 2396930)
-- Name: systemnote_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('systemnote_seq', 4, true);


--
-- TOC entry 18 (OID 2396978)
-- Name: calendar_groups_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('calendar_groups_seq', 17, true);

CREATE TABLE im (
    msg_id integer DEFAULT nextval('im_seq'::text) NOT NULL,
    source_id integer,
    dest_id integer,
    message text,
    date timestamp with time zone
);

CREATE SEQUENCE im_seq;

CREATE TABLE dictionaries (
    person_id integer NOT NULL,
    "language" text NOT NULL,
    word text NOT NULL
);

CREATE TABLE contact_groups (
    group_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    group_name text NOT NULL,
    group_description text,
    contacts integer[] DEFAULT '{}'::integer[] NOT NULL
);


ALTER TABLE ONLY contact_groups
    ADD CONSTRAINT contact_groups_pkey PRIMARY KEY (group_id);

ALTER TABLE ONLY dictionaries
    ADD CONSTRAINT dictionaries_pkey PRIMARY KEY (person_id, "language", word);

ALTER TABLE ONLY contact_groups
    ADD CONSTRAINT "$1" FOREIGN KEY (group_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;

COPY settings (setting_key, value, is_configurable, treepos) FROM stdin;
client_field	KGxwMQpWQWNjb3VudGluZwpwMgphVkFkdmVydGlzaW5nCnAzCmFWQWVyb3NwYWNlCnA0CmFWQWdy\naWN1bHR1cmUKcDUKYVZBdXRvbW90aXZlCnA2CmFWQmlvdGVjaG5vbG9neQpwNwphVkNoZW1pY2Fs\ncwpwOAphVkNvbW11bmljYXRpb25zCnA5CmFWQ29uc3VsdGluZwpwMTAKYVZDb25zdW1lciBQcm9k\ndWN0cwpwMTEKYVZFZHVjYXRpb24KcDEyCmFWRWxlY3Ryb25pY3MKcDEzCmFWRW5lcmd5L1V0aWxp\ndHkKcDE0CmFWRW5naW5lZXJpbmcKcDE1CmFWRW50ZXJ0YWlubWVudApwMTYKYVZGaW5hbmNhbApw\nMTcKYVZGb29kCnAxOAphVkdvdmVybm1lbnQKcDE5CmFWSGFyZHdhcmUKcDIwCmFWSGVhbHRoY2Fy\nZQpwMjEKYVZJbnN1cmFuY2UKcDIyCmFWTGVnYWwKcDIzCmFWTWFudWZhY3R1cmluZwpwMjQKYVZN\nZWRpYQpwMjUKYVZOZXR3b3JraW5nCnAyNgphVk5vdCBmb3IgUHJvZml0CnAyNwphVlByb2Zlc3Np\nb25hbCBTZXJ2aWNlcwpwMjgKYVZSZWFsIEVzdGF0ZQpwMjkKYVZSZWNyZWF0aW9uCnAzMAphVlJl\ndGFpbApwMzEKYVZTaGlwcGluZwpwMzIKYVZTb2Z0d2FyZQpwMzMKYVZUZWNobm9sb2d5CnAzNAph\nVlRlbGVjb21tdW5pY2F0aW9ucwpwMzUKYVZUcmFuc3BvcnRhdGlvbgpwMzYKYVZUcmF2ZWwKcDM3\nCmFWT3RoZXIKcDM4CmEu\n	1	\N
client_ownership	KGxwMQpWUHJpdmF0ZWx5IG93bmVkCnAyCmFWR292ZXJtZW50CnAzCmFWVGhpcmQgc2VjdG9yCnA0\nCmEu\n	1	\N
client_type	KGxwMQpWQ2xpZW50CnAyCmFWQ29tcGV0aXRvcgpwMwphVlBhcnRuZXIKcDQKYVZQcm9zcGVjdApw\nNQphLg==\n	1	\N
currency_prefix	KGxwMQpWJAphLg==\n	1	\N
currency_suffix	KGxwMQou\n	1	\N
opportunity_client_type	KGxwMQpWTmV3IEJ1c2luZXNzCnAyCmFWRXhpc3RpbmcgQnVzaW5lc3MKcDMKYVZBZGQtT24gQnVz\naW5lc3MKcDQKYVZNYWludGVuYW5jZQpwNQphVlVwZ3JhZGUKcDYKYVZTZXJ2aWNlcwpwNwphLg==\n	1	\N
opportunity_key_requirement	KGxwMQpWRmFzdCBkZXBsb3ltZW50CnAyCmFWRnVsbCByZXBvcnRpbmcKcDMKYVZFYXNlIG9mIHVz\nZQpwNAphVkJyZWFkdGggb2YgRnVuY3Rpb25hbGl0eQpwNQphVkNvbXBldGl0aXZlIHByaWNpbmcK\ncDYKYS4=\n	1	\N
opportunity_lead_source	KGxwMQpWQWR2ZXJ0aXNlbWVudApwMgphVkNvbGQgQ2FsbApwMwphVkVtcGxveWVlIFJlZmVycmFs\nCnA0CmFWRXh0ZXJuYWwgUmVmZXJyYWwKcDUKYVZQYXJ0bmVyCnA2CmFWUHVibGljIFJlbGF0aW9u\ncwpwNwphVldlYiBTZW1pbmFyCnA4CmFWVHJhZGUgU2hvdwpwOQphVldlYgpwMTAKYVZXb3JkIG9m\nIG1vdXRoCnAxMQphVk90aGVyCnAxMgphLg==\n	1	\N
opportunity_lost_reason	KGxwMQpWTGFjayBvZiBCdWRnZXQKcDIKYVZObyBQdXJjaGFzZSBNYWRlCnAzCmFWUG9vciByZXBv\ncmUgd2l0aCBzYWxlcyB0ZWFtCnA0CmFWUHJpY2UKcDUKYVZQcm9kdWN0IGxpbWl0YXRpb24KcDYK\nYVZTZXJ2aWNlcyBjYXBhYmlsaXRpZXMKcDcKYVZDb21wZXRpdG9yCnA4CmFWVW5rbm93bgpwOQph\nLg==\n	1	\N
product_groups	KGxwMQpWSGFyZHdhcmU6IFNlcnZlcnMKcDIKYVZIYXJkd2FyZTogRGVza3RvcHMKcDMKYVZIYXJk\nd2FyZTogTGFwdG9wcwpwNAphVkhhcmR3YXJlOiBQREFzCnA1CmFWU29mdHdhcmU6IEluc3RhbGxh\ndGlvbgpwNgphVlNvZnR3YXJlOiBMaWNlbnNlcwpwNwphVlN1cHBvcnQKcDgKYVZUcmFpbmluZwpw\nOQphLg==\n	1	\N
\.

ALTER TABLE persons ADD person_flags integer;
UPDATE persons SET person_flags=0;
ALTER TABLE persons ALTER person_flags SET DEFAULT 0;
ALTER TABLE persons ALTER person_flags SET NOT NULL;

ALTER TABLE item_rels ADD relation_flags integer;
UPDATE item_rels SET relation_flags=0;
ALTER TABLE item_rels ALTER relation_flags SET DEFAULT 0;
ALTER TABLE item_rels ALTER relation_flags SET NOT NULL;

ALTER TABLE ONLY settings DROP CONSTRAINT "$1";
ALTER TABLE ONLY settings
    ADD CONSTRAINT "$1" FOREIGN KEY (treepos) REFERENCES items(treepos) ON UPDATE CASCADE ON DELETE CASCADE;

INSERT INTO item_types VALUES ( 24, 'Virtual folders', 'fld.gif');
INSERT INTO item_types VALUES ( 25, 'Messages', 'message.gif');
INSERT INTO item_types VALUES ( 26, 'Translation', 'translation.gif');
INSERT INTO item_types VALUES ( 27, 'Service', 'services.gif');
INSERT INTO item_types VALUES ( 28, 'Translation', 'document.gif');

CREATE TABLE messages (
    message_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    message_source integer NOT NULL,
    sender_org_id integer,
    sender_org_name text,
    sender_nr text,
    receiver_org_id integer,
    receiver_org_name text,
    receiver_person_id integer,
    receiver_person_name text,
    responsible_person integer,
    message_contents text,
    message_type text,
    delivery_method text,
    priority text,
    date_dispatch timestamp with time zone,
    date_arrival timestamp with time zone,
    date_deadline timestamp with time zone,
    date_answered timestamp with time zone,
    message_title text NOT NULL
);
ALTER TABLE ONLY messages
    ADD CONSTRAINT messages_pkey PRIMARY KEY (message_id);
ALTER TABLE ONLY messages
    ADD CONSTRAINT "$1" FOREIGN KEY (message_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


CREATE TABLE virt_folders (
    virt_folder_id integer DEFAULT currval('item_id_seq'::text) NOT NULL,
    folder_name character varying(128),
    comments text
);
ALTER TABLE ONLY virt_folders
    ADD CONSTRAINT virt_folders_pkey PRIMARY KEY (virt_folder_id);
ALTER TABLE ONLY virt_folders
    ADD CONSTRAINT "$1" FOREIGN KEY (virt_folder_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;


ALTER TABLE ONLY im
    ADD CONSTRAINT im_pkey PRIMARY KEY (msg_id);

alter table efolders add eaccount_id integer;
alter table emails add eaccount_id integer;
create index efolders_account_ndx on efolders ( eaccount_id );
create table imap_emails (
  folder_id int4 not null,
  imap_uid int4 not null,
  conflux_id int4 not null );
ALTER TABLE ONLY imap_emails
    ADD CONSTRAINT imap_emails_pkey PRIMARY KEY (folder_id, imap_uid, conflux_id);
create index imap_emails_ndx on imap_emails ( conflux_id );
create index todos_workflow_ndx on todos ( workflow_id );
alter table events add master_id integer;
create index event_master_ndx on events ( master_id );
alter table emails add email_to_addr text;
create sequence custom_field_seq;
create table custom_fields (field_id integer,toporg_id integer,item_type_id integer,field_name text,priority integer,type integer,size integer);
alter table custom_fields alter field_id set not null;
alter table custom_fields alter field_id SET DEFAULT nextval('custom_field_seq'::text);
create table custom_rows (item_id integer,field_id integer,contents text);
ALTER TABLE custom_fields ADD CONSTRAINT custom_fields_pkey PRIMARY KEY (field_id);
ALTER TABLE custom_rows ADD CONSTRAINT custom_rows_pkey PRIMARY KEY (item_id, field_id);
CREATE INDEX custom_fields_ndx on custom_fields ( toporg_id, item_type_id );
ALTER TABLE ONLY custom_rows ADD CONSTRAINT "$1" FOREIGN KEY (item_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;
ALTER TABLE ONLY custom_rows ADD CONSTRAINT "$2" FOREIGN KEY (field_id) REFERENCES custom_fields(field_id) ON UPDATE RESTRICT ON DELETE CASCADE;
ALTER TABLE ONLY custom_fields ADD CONSTRAINT "$1" FOREIGN KEY (toporg_id) REFERENCES items(item_id) ON UPDATE RESTRICT ON DELETE CASCADE;

alter table persons add email_notify2 integer;
alter table persons alter email_notify2 set default 0;
update persons set email_notify2=0;
alter table persons alter email_notify2 set not null;

ALTER TABLE eaccounts ADD eaccount_sendername text;
ALTER TABLE eaccounts ADD eaccount_sendermail text;
INSERT INTO settings values ('conflux_version', '1.3.1', 0, null);
--
-- TOC entry 20 (OID 2434766)
-- Name: log_batch_seq; Type: SEQUENCE SET; Schema: public; Owner: conflux
--

SELECT pg_catalog.setval('log_batch_seq', 19580, true);

insert into access_rights ( item_id, group_id, right_id, treepos ) values ( 3, 1, 2, (select treepos from items where item_id=3));
