#!/usr/bin/python2.3
import sys, signal, os, time, tempfile, base64, email, cStringIO, mx.DateTime, cPickle

PID_FILE = "/tmp/confluxd.pid"
tempfile.tempdir = "/tmp/"
REQUEST = None

    

# Logs
def log_message(message, error=0):
    if error:
        sys.stdout.write("%s: ERROR: %s\n" % (time.strftime("%Y-%m-%d %H:%M:%S"), message))
    else:
        sys.stdout.write("%s: LOG: %s\n" % (time.strftime("%Y-%m-%d %H:%M:%S"), message))
    sys.stdout.flush()

# Initialize signals
def exit_fault(signum):
    global REQUEST
    if REQUEST is not None:
        REQUEST.close()
    os.unlink(PID_FILE)
    log_message('Conflux Daemon caught signal %d, exiting.' % signum, error=1)
    raise
    sys.exit()

# Set up pid file
def deamonize(stdout='/dev/null', stderr=None, stdin='/dev/null',
              pidfile=None, startmsg = 'started with pid %s' ):
    try:
        pid = os.fork()
        if pid > 0: sys.exit(0) # Exit first parent.
    except OSError, e: 
        sys.stderr.write("fork #1 failed: (%d) %s\n" % (e.errno, e.strerror))
        sys.exit(1)

    os.chdir("/")
    os.umask(0) 
    os.setsid() 

    try: 
        pid = os.fork()
        if pid > 0: sys.exit(0) # Exit second parent.
    except OSError, e:
        sys.stderr.write("fork #2 failed: (%d) %s\n" % (e.errno, e.strerror))
        sys.exit(1)

    if not stderr: stderr = stdout
    si = file(stdin, 'r')
    so = file(stdout, 'a+')
    se = file(stderr, 'a+', 0)
    pid = str(os.getpid())
    sys.stderr.write("\n%s\n" % startmsg % pid)
    sys.stderr.flush()
    if pidfile:
        tempname = tempfile.mktemp()
        fp = open(tempname,'w+b')
        fp.write(pid)
        fp.close()
        try:
            os.link(tempname, pidfile)
        except OSError: # pid-file already exists, do not start.
            log_message('Pidfile %s exists, exiting. If you are sure that\nthe daemon is currently not running, remove the file and start\nthe daemon again.' % PID_FILE, 1)
            os.unlink(tempname)
            sys.exit(1)
        os.unlink(tempname)

    os.dup2(si.fileno(), sys.stdin.fileno())
    os.dup2(so.fileno(), sys.stdout.fileno())
    os.dup2(se.fileno(), sys.stderr.fileno())
    log_message("Daemon started.", 0)


def startstop(stdout='/dev/null', stderr=None, stdin='/dev/null',
              pidfile=PID_FILE, startmsg = 'started with pid %s' ):
    if len(sys.argv) > 1:
        action = sys.argv[1]
        try:
            pf  = file(pidfile,'r')
            pid = int(pf.read().strip())
            pf.close()
        except IOError:
            pid = None
        if 'stop' == action or 'restart' == action:
            if not pid:
                mess = "Could not stop, pid file '%s' missing.\n"
                sys.stderr.write(mess % pidfile)
                sys.exit(1)
            try:
               while 1:
                   os.kill(pid,signal.SIGTERM)
                   time.sleep(1)
            except OSError, err:
               err = str(err)
               if err.find("No such process") > 0:
                   os.remove(pidfile)
                   if 'stop' == action:
                       sys.exit(0)
                   action = 'start'
                   pid = None
               else:
                   print str(err)
                   sys.exit(1)
        if 'start' == action:
            if pid:
                mess = "Start aborted since pid file '%s' exists.\n"
                sys.stderr.write(mess % pidfile)
                sys.exit(1)
            deamonize(stdout,stderr,stdin,pidfile,startmsg)
            return
    print "usage: %s start|stop|restart" % sys.argv[0]
    sys.exit(2)


def main():
    # Set up module import path  FIXME
    sys.path.append('/var/lib/conflux/lib/')

    # Real daemon code
    try:
        import _Conf, _Baselib, _Indexer, _RootObject, _InitTypes, _mail, _calendar, _Utils, _Efolder, _Event, _Conf
        import _Eaccount, _Email, _eventlib

        INDEXABLE_TYPES = [_InitTypes.ITEM_TYPE_DOCUMENT, _InitTypes.ITEM_TYPE_EMAIL]


        REQUEST = _Baselib.Request(None)
        fp = None



        TIMES = 0
        while 1: # Main cycle
            TIMES += 1

            # recurring events
            if TIMES % 900 == 0:
                REQUEST.db.execute("""SELECT e.event_id, e.repeat_type, (SELECT count(*) FROM events e2 WHERE e2.master_id=e.event_id AND e2.start_stamp > now()) AS count_all FROM  events e WHERE  e.master_id=1""")
                res = REQUEST.db.fetchall()
                log_message(res)
                for row in res:
                    if row[1]==_Event.REPEAT_DAY and row[2]<_Conf.REPEAT_DAY_TRESHOLD:
                        _eventlib.insert_events(REQUEST, row[0], _Conf.REPEAT_DAY_TRESHOLD-row[2])
                    elif row[1]==_Event.REPEAT_WEEK and row[2]<_Conf.REPEAT_WEEK_TRESHOLD:
                        _eventlib.insert_events(REQUEST, row[0], _Conf.REPEAT_WEEK_TRESHOLD-row[2])
                    elif row[1]==_Event.REPEAT_MONTH and row[2]<_Conf.REPEAT_MONTH_TRESHOLD:
                        _eventlib.insert_events(REQUEST, row[0], _Conf.REPEAT_MONTH_TRESHOLD-row[2])
                    elif row[1]==_Event.REPEAT_YEAR and row[2]<_Conf.REPEAT_YEAR_TRESHOLD:
                        _eventlib.insert_events(REQUEST, row[0], _Conf.REPEAT_YEAR_TRESHOLD-row[2])
                    else:
                        pass

            for round_time in range(3):
                # Indexing, oldest first
                SQL = u"""SELECT item_id, item_type_id FROM items WHERE index_this_item = 1 ORDER BY item_id ASC LIMIT 1""".encode('UTF8')
                REQUEST.db.execute(SQL)
                result = REQUEST.db.dictfetchone()
                if result and result['item_type_id'] in INDEXABLE_TYPES:
                    obj = _RootObject.dispatch_item(REQUEST, result['item_id'])
                    if obj.item_type_id == _InitTypes.ITEM_TYPE_DOCUMENT:
                        try:
                            fp = open(obj.get_path().encode('UTF8'))
                            _Indexer.delete_index(REQUEST, obj.get_id())
                            _Indexer.index_file(REQUEST, fp, obj.get_path(), obj.get_id())
                            if not fp.closed:
                                fp.close()
                            REQUEST.db.execute("""UPDATE items SET index_this_item = 0 WHERE item_id=%d""" % obj.get_id())
                            REQUEST.db.commit()
                            log_message('Indexed object %d: document.' % obj.get_id())
                        except:
                            if not fp.closed:
                                fp.close()
                            REQUEST.db.rollback()
                            log_message('Failed indexing object %d: document.' % obj.get_id(), 1)
                            REQUEST.db.execute("""UPDATE items SET index_this_item = 2 WHERE item_id=%d""" % obj.get_id())
                            REQUEST.db.commit()
                    elif obj.item_type_id == _InitTypes.ITEM_TYPE_EMAIL:
                        try:
                            message = _mail.message_from_string(base64.decodestring(obj.get('email_contents')))
                            fp = cStringIO.StringIO(_mail.indexify_message(REQUEST, message).encode('UTF8'))
                            fp.seek(0)
                            _Indexer.delete_index(REQUEST, obj.get_id())
                            _Indexer.index_file(REQUEST, fp, 'whatever.txt', obj.get_id())
                            if not fp.closed:
                                fp.close()
                            REQUEST.db.execute("""UPDATE items SET index_this_item = 0 WHERE item_id=%d""" % obj.get_id())
                            REQUEST.db.commit()
                            log_message('Indexed object %d: email.' % obj.get_id())
                        except:
                            if not fp.closed:
                                fp.close()
                            REQUEST.db.rollback()
                            log_message('Failed indexing object %d: message.' % obj.get_id(), 1)
                            REQUEST.db.execute("""UPDATE items SET index_this_item = 2 WHERE item_id=%d""" % obj.get_id())
                            REQUEST.db.commit()
                    else:
                        log_message('Failed indexing object %d: unknown type.' % obj.get_id(), 1)
                        REQUEST.db.execute("""UPDATE items SET index_this_item = 2 WHERE item_id=%d""" % obj.get_id())
                        REQUEST.db.commit()
                elif not result: break
                elif result['item_type_id'] not in INDEXABLE_TYPES:
                    log_message('Failed indexing object %d: unknown type.' % result['item_id'], 1)
                    REQUEST.db.execute("""UPDATE items SET index_this_item = 2 WHERE item_id=%d""" % result['item_id'])
                    REQUEST.db.commit()

            # E-mail reminder
            if TIMES % 5 == 0:
                now = _Utils.utc_now_mx()
                SQL = """SELECT
 i.creator_id,
 p.e_mail,
 p.phone_cell,
 e.start_stamp AS utc_start_stamp, -- compatibility
 e.*
FROM events e, items i, persons p
WHERE
 i.item_id=e.event_id AND
 i.parent_id=p.person_id AND
 remind_type <> 0 AND
 remind_time is not null AND
 (start_stamp-remind_time) between (now()-'1 minutes'::interval) and (now()+'1 minutes'::interval) AND
 (last_reminder is null or last_reminder < (now() - '10 minutes'::interval))"""
                REQUEST.db.execute(SQL)
                data = REQUEST.db.dictfetchall()

                for event in data:
                    if not event['remind_type'] or not event['remind_time']:
                        continue
                    try:
                        if event['remind_type'] == 1:
                            _mail.send_reminder(event, REQUEST)
                            REQUEST.db.execute("""UPDATE events set last_reminder=now() WHERE event_id=%d""" % event['event_id'])
                            log_message('Sent reminder to %s from event %d' % (event['e_mail'].decode('UTF8'), event['event_id']))
                        elif event['remind_type'] == 2:
                            _mail.send_reminder(event, REQUEST)
                            REQUEST.db.execute("""UPDATE events set last_reminder=now() WHERE event_id=%d""" % event['event_id'])
                            log_message('Sent reminder to %s from event %d' % (event['phone_cell'].decode('UTF8'), event['event_id']))
                    except:
                        log_message('Failed sending a reminder from event %d' % event['event_id'], 1)
                REQUEST.db.commit()

            # E-mail autodelete
            if TIMES % 15 == 0:
                REQUEST.db.execute("""SELECT i.item_id, b.value
FROM
 items i,
 persons p,
 settings a,
 settings b
WHERE
 i.item_id=p.person_id AND
 i.treepos=a.treepos AND
 i.treepos=b.treepos AND
 a.setting_key='email_deleteold' AND
 b.setting_key='email_deletedays' AND
 a.value='STEKLg==\n'""")
                users = REQUEST.db.fetchall()
                for row in users:
                    days = cPickle.loads(base64.decodestring(row[1]))
                    REQUEST.db.execute("""SELECT e.efolder_id FROM items i, efolders e WHERE i.item_id=e.efolder_id AND i.creator_id=%d AND (e.efolder_flags & %d) <> 0""" % (row[0], _Efolder.EFOLDER_DELETED))
                    folders = map(lambda x: x[0], REQUEST.db.fetchall())
                    for folder in folders:
                        REQUEST.db.execute("""SELECT e.email_id FROM items i, emails e WHERE e.email_id=i.item_id AND i.parent_id=%d AND i.create_time < now()-'%d days'::interval""" % (folder, days))
                        for email in map(lambda x: x[0], REQUEST.db.fetchall()):
                            try:
                                email_obj = _RootObject.dispatch_item(REQUEST, email)
                                email_obj.delete()
                                log_message('Autodeleted e-mail %d.' % email)
                                REQUEST.db.commit()
                            except:
                                log_message('Autodeleting e-mail %d failed.' % email)
                                REQUEST.db.rollback()

            if TIMES % 14400 == 0 and (time.localtime()[3] <= 3 or time.localtime()[3] >= 20):
                log_message('Running "vacuum analyze;".')
                REQUEST.db.execute("commit; VACUUM ANALYZE; begin;")

            # Take a nap
            REQUEST.db.commit()
            time.sleep(1)
    except:
        exit_fault(-1)

    # Clean up
    REQUEST.close()
    os.unlink(PID_FILE)

if __name__ == "__main__":
    startstop(stdout='/tmp/confluxd.log')
    main()

