import _Conf, _InitTypes, _Utils, _RootObject, _Exceptions, _Access
import mx.DateTime

mxtype = type(mx.DateTime.now())

# Map for DAV props vs Conflux fields
DAV_FIELDS = {   'creationdate': -1, # 'create_time',
                 'displayname': -1,
                 'getcontentlanguage': -1,
                 'getcontentlength': 'item_size',
                 'getcontenttype': -1,
                 'getetag': -1,
                 'getlastmodified': 'edit_time',
                 'lockdiscovery': -1,
                 'resourcetype': 'resourcetype',
                 'source': -1,
                 'supportedlock': -1,
                 'checked-in': None,
                 'checked-out': None,
           }

class DAVobject:
    def TLS(self, key):
        return key

    def __init__(self, REQUEST, uri, item_id=None):
        if item_id is None:
            if uri[0] <> '/':
                raise RuntimeError, self.TLS('Relative URIs cannot be loaded!')
            self.uri = uri
            uri_parts = filter(None, self.uri.split('/'))
#            if not uri_parts:
#                raise RuntimeError, self.TLS('Invalid URI received!')

            # Locate object in database
            parent_id = _Conf.ROOTOBJECT
            item_type_id = None
            item_types = ",".join(map(str, [_InitTypes.ITEM_TYPE_ORGANIZATION, _InitTypes.ITEM_TYPE_FOLDER, _InitTypes.ITEM_TYPE_DOCUMENT]))
            SQL = """\
    SELECT
     i.item_id,
     i.item_type_id,
     d.filename,
     f.folder_name,
     o.organization_name
    FROM
     items i
    LEFT JOIN documents d ON d.document_id=i.item_id
    LEFT JOIN folders f ON f.folder_id=i.item_id
    LEFT JOIN organizations o ON o.organization_id=i.item_id
    WHERE
     i.parent_id=%(parent_id)d AND
     i.item_type_id in ( %(item_types)s )
    """

            if uri_parts:
                for uri_part in uri_parts:
                    uri_part = _Utils.make_path(uri_part).encode('UTF8')
                    REQUEST.db.execute(SQL % locals())
                    res = REQUEST.db.fetchall()
                    parent_id = None
                    for row in res:
                        if row[2] and _Utils.make_path(row[2]) == uri_part: # document
                            parent_id = row[0]
                            item_type_id = row[1]
                            break
                        elif row[3] and _Utils.make_path(row[3]) == uri_part: # folder
                            parent_id = row[0]
                            item_type_id = row[1]
                            break
                        elif row[4] and _Utils.make_path(row[4]) == uri_part: # org
                            parent_id = row[0]
                            item_type_id = row[1]
                            break
                    if parent_id is None:
                        raise RuntimeError, self.TLS('Given URI \'%s\' does not resolve to a Conflux object!' % self.uri)
            else:
                parent_id = _Conf.ROOTOBJECT
                REQUEST.db.execute("""\
    SELECT
     i.item_id,
     i.item_type_id,
     '' as filename,
     '' as folder_name,
     o.organization_name
    FROM
     items i
    LEFT JOIN organizations o ON o.organization_id=i.item_id
    WHERE
     i.item_id=%(parent_id)d""" % locals())
                row = REQUEST.db.fetchone()
                item_type_id = row[1]

            if parent_id is None:
                raise RuntimeError, self.TLS('Given URI \'%s\' does not resolve to a Conflux object!' % self.uri)

            self.real_name = row[2] or row[3] or row[4]
            self.item_id = parent_id
            self.item_type_id = item_type_id
            self.uri = _Conf.DAV_URL + self.uri[1:]
        else:
            REQUEST.db.execute("""SELECT item_id, item_type_id FROM items WHERE item_id=%d""" % item_id)
            res = REQUEST.db.fetchone()
            self.item_id = parent_id = res[0]
            self.item_type_id = res[1]
            self.uri = None

        if self.item_type_id == _InitTypes.ITEM_TYPE_DOCUMENT:
            table_name = 'documents'
            field_name = 'document_id'
        elif self.item_type_id == _InitTypes.ITEM_TYPE_FOLDER:
            table_name = 'folders'
            field_name = 'folder_id'
        elif self.item_type_id == _InitTypes.ITEM_TYPE_ORGANIZATION:
            table_name = 'organizations'
            field_name = 'organization_id'

        # Load object data from db
        REQUEST.db.execute("""\
SELECT
 i.*,
 o.*
FROM
 items i,
 %(table_name)s o
WHERE
 i.item_id=o.%(field_name)s AND
 i.item_id=%(parent_id)d
""" % locals())
        self.__itemdata__ = REQUEST.db.dictfetchone()
        if item_id is not None:
            if self.item_type_id == _InitTypes.ITEM_TYPE_DOCUMENT:
                self.real_name = _Utils.make_path(self.__itemdata__['filename'])
            elif self.item_type_id == _InitTypes.ITEM_TYPE_FOLDER:
                self.real_name = _Utils.make_path(self.__itemdata__['folder_name'])
            elif self.item_type_id == _InitTypes.ITEM_TYPE_ORGANIZATION:
                self.real_name = _Utils.make_path(self.__itemdata__['organization_name'])
        self.__itemdata__['real_name'] = self.real_name
        if self.item_type_id in [_InitTypes.ITEM_TYPE_ORGANIZATION, _InitTypes.ITEM_TYPE_FOLDER]:
            self.__itemdata__['resourcetype'] = 1
        else:
            self.__itemdata__['resourcetype'] = 0

    def get(self, key):
        if self.__itemdata__.has_key(key):
            value = self.__itemdata__[key]
        else:
            value = None
        if isinstance(value, str):
            value = value.decode('UTF8')
        return value

    def get_prop(self, ns, name):
        if ns == 'DAV:':
            if not DAV_FIELDS.has_key(name) or DAV_FIELDS[name] == -1:
                raise _Exceptions.DAV_noshow
            val = self.get(DAV_FIELDS[name])
        else:
            raise RuntimeError, self.TLS('Unknown ns for get_prop(): [%s, %s]' % (ns, name))
        if type(val) == mxtype:
            val = val.strftime('%a, %d %h %Y %H:%M:%S GMT')
        if val is None:
            raise _Exceptions.DAV_notimpl, self.TLS('Empty val in get_prop(): [%s, %s]' % (ns, name))
        else:
            return val

    def get_children(self, REQUEST):
        item_types = ",".join(map(str, [_InitTypes.ITEM_TYPE_ORGANIZATION, _InitTypes.ITEM_TYPE_FOLDER, _InitTypes.ITEM_TYPE_DOCUMENT]))
        right_param = _Access.select_param(REQUEST.USER.get_id(), _Access.ACCESS_READ, [_InitTypes.ITEM_TYPE_ORGANIZATION, _InitTypes.ITEM_TYPE_FOLDER, _InitTypes.ITEM_TYPE_DOCUMENT])
        if right_param:
            right_param = " AND %s" % right_param
        Q = u"""SELECT item_id
FROM
 items i
LEFT JOIN documents d ON d.document_id=i.item_id
WHERE
 i.parent_id=%d AND i.item_type_id in ( %s ) AND 
 i.item_id<>%d AND d.final_version_id IS NULL%s
ORDER by item_type_id, item_name""" % (self.item_id, item_types, _Conf.ROOTOBJECT, right_param)
        REQUEST.db.execute(Q.encode('UTF8'))
        res = REQUEST.db.fetchall()
        children = []
        for row in res:
            children.append(DAVobject(REQUEST, None, row[0]))
        return children

    def get_uri(self, REQUEST):
        if self.uri is None:
            obj = _RootObject.dispatch_item(REQUEST, self.item_id)
            if _Conf.BASE_DOCUMENT_PATH[-1] == '/':
                self.uri = obj.get_path().replace(_Conf.BASE_DOCUMENT_PATH, _Conf.DAV_URL)
            else:
                self.uri = obj.get_path().replace(_Conf.BASE_DOCUMENT_PATH+'/', _Conf.DAV_URL)
            # append extra / to folders
        if self.item_type_id in [_InitTypes.ITEM_TYPE_ORGANIZATION, _InitTypes.ITEM_TYPE_FOLDER] and self.uri[-1] <> '/':
            self.uri += '/'
        return self.uri
      
