from email import Header
from email import Errors
from email import Encoders
from email.MIMENonMultipart import MIMENonMultipart
import mimetypes

class MIMEFile(MIMENonMultipart):
    """Class for generating whatever type MIME documents."""

    def __init__(self, _filedata, _filename, _type=None,
                 _encoder=Encoders.encode_base64, **_params):
        """Create whatever type MIME document.

        _filedata is a string containing the raw image data.

        _encoder is a function which will perform the actual encoding for
        transport of the file data.  It takes one argument, which is this
        fileinstance.  It should use get_payload() and set_payload() to
        change the payload to the encoded form.  It should also add any
        Content-Transfer-Encoding or other headers to the message as
        necessary.  The default encoding is Base64.

        Any additional keyword arguments are passed to the base class
        constructor, which turns them into parameters on the Content-Type
        header.
        """
        if _type is None and _filename:
            _type = mimetypes.guess_type(_filename)[0]
            if _type:
                main, sub = _type.split('/')
        else:
            main, sub = _type.split('/')
        if _type is None:
            _type = 'application/octet-stream'
            main = 'application'
            sub = 'octet-stream'
        if _filename is None:
            raise TypeError, 'Could not find file name'
        MIMENonMultipart.__init__(self, main, sub, **_params)
        self.set_payload(_filedata)
        if _filename:
            self.add_header('Content-Disposition', 'attachment', filename=Header.Header(_filename).encode())
        else:
            self.add_header('Content-Disposition', 'inline')
        _encoder(self)
