import _Access, _Conf, _InitTypes, _Utils
import os, time

class SQLTree:
    QUERY = """\
SELECT
 i.item_id,
 i.parent_id,
 i.item_name,
 i.treepos,
 i.item_type_id,
 %(add_fields)sit.item_type_icon
FROM
 items i,
 item_types it
WHERE
 i.item_id <> 0 AND
 i.item_type_id=it.item_type_id %(item_type_check)s%(right_param)s
ORDER BY i.item_type_id, i.item_name"""
    DOCQUERY = """\
SELECT
 i.item_id,
 i.parent_id,
 i.item_name,
 i.treepos,
 i.item_type_id,
 d.filename,
 %(add_fields)sit.item_type_icon
FROM
 items i
LEFT JOIN item_types it ON i.item_type_id=it.item_type_id
LEFT JOIN documents d ON i.item_id=d.document_id
WHERE
 i.item_id <> 0 AND
 it.item_type_id is not null AND
 d.final_version_id is NULL %(item_type_check)s%(right_param)s
ORDER BY i.item_type_id, i.item_name"""

    def __init__(self, REQUEST, treename):
        self._conf = {}
        self.REQUEST = REQUEST
        self.set_param('treename', treename)
        self.tree = None
        self.forbidden = []
        try:
            self.open_paths = REQUEST.get_setting('tree_'+self.get_param('treename'))
        except:
            self.open_paths = []

    def set_param(self, name, value):
        self._conf[name] = value

    def get_param(self, name, ifnull=None):
        try:
            return self._conf[name]
        except:
            if ifnull is not None:
                return ifnull
            raise   

    def getquery(self):
        ns = {}
        right_param = _Access.select_param(self.REQUEST.USER.get_id(), _Access.ACCESS_READ, self.get_param('item_types'))
        if right_param:
            right_param = " AND " + right_param
        ns['right_param'] = right_param
        if self.get_param('item_types'):
            ns['item_type_check'] = " AND i.item_type_id in ( %s )" % ",".join(map(str, self.get_param('item_types')))
        else:
            ns['item_type_check'] = ""
        if self.get_param('add_fields', 0):
            ns['add_fields'] = "%s,\n" % ",\n ".join(self.get_param('add_fields'))
        else:
            ns['add_fields'] = ""
        if _InitTypes.ITEM_TYPE_DOCUMENT in self.get_param('item_types', [_InitTypes.ITEM_TYPE_DOCUMENT]):
            self.is_doc_tree = 1
            return (self.DOCQUERY % ns).encode('UTF8')
        else:
            self.is_doc_tree = 0
            return (self.QUERY % ns).encode('UTF8')

    def maketree(self):
        self.REQUEST.db.execute(self.getquery())
        data = self.REQUEST.db.dictfetchall()
        child_map = {}
        ids_map = {}
        for row in data:
            try:
                child_map[row['parent_id']].append(row)
            except:
                child_map[row['parent_id']] = [row]
            ids_map[row['item_id']] = 1
        self.tree = Node(data, treeobj=self, child_map=child_map, ids_map=ids_map)
        if self.get_param('disc_filter_childless', 0):
            self.tree.disc_clean_children()

    def getTree(self):
        if self.tree:
            BASE_ICON_URL = _Conf.BASE_ICON_URL
            BASE_GENERAL_URL = _Conf.BASE_GENERAL_URL
            BASE_WEB_URL = _Conf.BASE_WEB_URL
            SERVER_URL = self.REQUEST.SERVER_URL
            tree_output = self.tree.printTree(self.REQUEST, treeobj=self)
            treename = self.get_param('treename')
            output = u"""
<script type="text/javascript" src="%(BASE_WEB_URL)sreq.js"></script>
<script type="text/javascript">
function set_treepath(item_id)
{
   SendRequest_RES('%(SERVER_URL)s%(BASE_GENERAL_URL)sinfo.py/tree_set?treename=%(treename)s&open_paths='+item_id);
}
function onoff(item_id){
  r = new Array();
  s = new Array();
  item_id = item_id;
  trs = document.getElementsByTagName("tr");
  el = document.getElementById("i"+item_id);
  is_open = 0;
  if(el.src.indexOf("plus")!=-1)
  {
      el.src='%(BASE_ICON_URL)sminus.gif';
      is_open = 1;
  }
  else
  {
      el.src='%(BASE_ICON_URL)splus.gif';
      is_open = 0;
  }
  for (var i = 0; i < trs.length; i++)
  {
    a = trs.item(i);
    if(a.id.indexOf(item_id)!=-1)
    {
        if(is_open)
        {
            len = a.id.indexOf(item_id);
            sub_str = a.id.substring(len);
            if(sub_str.split('|').length<=2)
                a.style.display="block";
        }
        else
        {
            len = a.id.indexOf(item_id);
            sub_str = a.id.substring(len);
            s = sub_str.split('|');
            if(s.length>=3)
            {
                s.reverse().pop();
                s.reverse().pop();
                r = r.concat(s);
            }
            a.style.display="none";
        }
    }
  }
  if(r.length>1)
  {
    s = new Array();
    for (i=1;i<=r.length;i++) 
    {
        found=false;
        for (k=i+1;k<=r.length;k++) 
        {
            if (r[i]==r[k]) 
                found=true;
        }
       if (!found)
       {
         s=s.concat(r[i]);
       }
    }
    for(a in s)
    {
       if(s[a])
       {
         el = document.getElementById("i"+s[a]);
         el.src='%(BASE_ICON_URL)splus.gif';
       }
    }
  }
  set_treepath(item_id);
}
</script>
%(tree_output)s""" % locals()
            return output
        else:
            return None

class Node:
    def __init__(self, data, treeobj, item=None, parent=None, child_map=None, ids_map=None):
        if item is None:
            self.item_id = _Conf.ROOTOBJECT
            self.item_name = 'ROOT'
            self.item_path = ''
            self.treepos = 'ROOT'
            self.parent_id = _Conf.ROOTOBJECT
            self.icon = 'X'
            self.item_type_id = -1
            self.parent = None
        else:
            self.item_id = item['item_id']
            self.item_name = item['item_name']
            if parent:
                self.item_path = parent.item_path + '/' + self.item_name.decode('UTF8')
            else:
                self.item_path = self.item_name.decode('UTF8')
            self.treepos = item['treepos']
            self.parent_id = item['parent_id']
            self.icon = item['item_type_icon']
            self.item_type_id = item['item_type_id']
            self.parent = parent
            if treeobj.is_doc_tree: self.doc_name = (item['filename'] or '').decode('UTF8')
        
        if isinstance(self.item_name, str):
            self.item_name = self.item_name.decode('UTF8')
        self._itemdata = {}
        for field in treeobj.get_param('add_fields', []):
            self._itemdata[field] = item[field]
        self.children = []
        self.find_children(child_map)
        for child in self.children:
            data.remove(child)
        self.load_children(data, treeobj, child_map, ids_map)
        if self.item_id == _Conf.ROOTOBJECT and data:
            for lost_child in data:
                if not ids_map.has_key(lost_child['parent_id']):
                    self.children.append( Node(data, treeobj, lost_child, parent=self, child_map=child_map, ids_map=ids_map) )

    def find_children(self, child_map):
         try:
             self.children = map(lambda x: x, child_map[self.item_id])
         except:
             self.children = []

    def load_children(self, data, treeobj, child_map, ids_map):
        children = self.children
        tmp = []
        for child in children:
            tmp.append( Node(data, treeobj, child, parent=self, child_map=child_map, ids_map=ids_map) )
        self.children = tmp

    def disc_clean_children(self):
        if self.children:
            childids = range(len(self.children))
            childids.reverse()
            for childid in childids:
                child = self.children[childid]
                child.disc_clean_children()
                if not child.children and child.item_type_id <> _InitTypes.ITEM_TYPE_DISCCATEGORY:
                    del child
                    del self.children[childid]

    def printTree(self, req, treeobj, level=0, display="block", idstr=""):
        output = []
        is_open_branch = 0
        if treeobj.get_param('is_open_tree', 0) or level == 1 or self.parent_id==_Conf.ROOTOBJECT or self.treepos in treeobj.open_paths or self.treepos == 'ROOT':
            is_open_branch = 1
        if level:
#            if level == 1:
#                ns = {'item_name':u"%s" % _Utils.html_quote(_Utils.shorten_string(self.item_name, 20)), 'item_id':self.item_id, 'parent_id':self.parent_id}
#            else:
            if treeobj.get_param('shorten', 0):
                ns = {'item_name':_Utils.html_quote(_Utils.shorten_string(self.item_name, 20)), 'item_id':self.item_id, 'parent_id':self.parent_id}
            else:
                ns = {'item_name':self.item_name, 'item_id':self.item_id, 'parent_id':self.parent_id}
            if treeobj.is_doc_tree:
                ns['doc_name'] = _Utils.html_quote_show(self.doc_name)
            for field in treeobj.get_param('add_fields', []):
                ns[field] = self._itemdata[field]
            ns['ts'] = time.time()
            ns['item_path'] = self.item_path
            ns['wend'] = ((level - 2) * 14) + 1
            ns['tree_url'] = treeobj.get_param('tree_url')
            ns['target_url'] = treeobj.get_param('target_url')
            ns['BASE_ICON_URL'] = _Conf.BASE_ICON_URL
            ns['params'] = treeobj.REQUEST.get_formstring(badkeys = ['open_paths','organization_id','timestamp','time'] + treeobj.forbidden)
            ns['params'] += u"open_paths=%s" % self.treepos
            if treeobj.get_param('target', 0):
                ns['target'] = u""" target="%s\"""" % treeobj.get_param('target')
            else:
                ns['target'] = u""
            if is_open_branch:
                ns['treeicon'] = u'minus.gif'
            else:
                ns['treeicon'] = u'plus.gif'
            if level==1:
                ns['children'] = u""
            elif self.children and not treeobj.get_param('is_open_tree', 0):
                ns['children'] = u"""<img src="%(BASE_ICON_URL)sspacer.gif" width="%(wend)d" height=1 border=0 alt=""><A  class="table_tree_link" href="javascript:onoff(%(item_id)d);"><IMG src="%(BASE_ICON_URL)s%(treeicon)s" id="i%(item_id)s" width=9 height=9 border=0 alt=""></A>""" % ns
            else:
                ns['children'] = u"""<img src="%(BASE_ICON_URL)sspacer.gif" width="%(wend)d" height=5 border=0 alt=""><IMG src="%(BASE_ICON_URL)sspacer.gif" width=9 height=9 border=0 alt="">""" % ns
            ns['urlparams'] = treeobj.get_param('urlparams', '') % ns
            if treeobj.get_param('js', 0):
                ns['urlstart'] = treeobj.get_param('js') % ns
                ns['urlend'] = "</A>"
            elif treeobj.get_param('urlparams', 0):
                ns['formstring'] = treeobj.REQUEST.get_formstring(badkeys = ['open_paths','organization_id','timestamp','parent_id']+treeobj.forbidden)
                ns['urlstart'] = u"""<A class="table_tree_link" href="%(target_url)s%(formstring)s%(urlparams)s"%(target)s>""" % ns
                ns['urlend'] = u"</A>"
            else:
                ns['urlstart'] = u""
                ns['urlend'] = u""
            if  not treeobj.get_param('limit_icons', 0) or self.item_type_id in treeobj.get_param('limit_icons', []):
                ns['itemicon'] = self.icon
                if self.item_type_id == _InitTypes.ITEM_TYPE_DOCUMENT and treeobj.is_doc_tree:
                    file_ext = os.path.splitext(self.doc_name or '')[-1]
                    if(_Conf.MIME_TYPES.has_key(file_ext)):
                        ns['itemicon'] =  _Conf.MIME_TYPES[file_ext]
                    else:
                        ns['itemicon'] =  _Conf.MIME_TYPES["unknown_ext"]
                elif self.item_type_id == _InitTypes.ITEM_TYPE_DOCUMENT:
                    file_ext = os.path.splitext(self.item_name or '')[-1]
                    if(_Conf.MIME_TYPES.has_key(file_ext)):
                        ns['itemicon'] =  _Conf.MIME_TYPES[file_ext]

                ns['itemicon'] = u"""<img src="%(BASE_ICON_URL)s%(itemicon)s" border=0 alt=""><img src="%(BASE_ICON_URL)sspacer.gif" width=5 height=1 border=0 alt="">""" % ns
            else:
                ns['itemicon'] = ""
            if treeobj.get_param('linked_types', []) and self.item_type_id not in treeobj.get_param('linked_types', []):
                ns['urlstart'] = u""
                ns['urlend'] = u""
            ns['idstr'] = idstr
            ns['display'] = display
            if level == 1:
                output.append( u"""\
<tr valign="bottom" id="%(idstr)s" style="display: %(display)s;">
  <td width=10><img src="%(BASE_ICON_URL)sspacer.gif" width=10 height=1 border=0 alt=""></td>
  <td valign="bottom" class="td_tree" width="100%%"><A name="%(item_id)d"></A>%(children)s%(urlstart)s<img src="%(BASE_ICON_URL)sspacer.gif" width=5 height=1 border=0 alt="">%(itemicon)s%(urlend)s %(urlstart)s<B>%(item_name)s</B>%(urlend)s</TD>
  <td width=5><img src="%(BASE_ICON_URL)sspacer.gif" width=5 height=1 border=0 alt=""></td>
</TR>""" % ns )
            else:
                output.append( u"""\
<tr valign="bottom" id="%(idstr)s" style="display: %(display)s;">
  <td width=10><img src="%(BASE_ICON_URL)sspacer.gif" width=10 height=1 border=0 alt=""></td>
  <td valign="bottom" class="td_tree" width="100%%"><A name="%(item_id)d"></A>%(children)s%(urlstart)s<img src="%(BASE_ICON_URL)sspacer.gif" width=5 height=1 border=0 alt="">%(itemicon)s%(urlend)s %(urlstart)s%(item_name)s%(urlend)s</TD>
  <td width=5><img src="%(BASE_ICON_URL)sspacer.gif" width=5 height=1 border=0 alt=""></td>
</TR>""" % ns )
        for child in self.children:
            idstr = idstr + "|" + str(self.item_id) + "|"
            idlist = idstr.split("|")
            idlist = filter(None, idlist)
            tmp = []
            for i in idlist:
                if i not in tmp:
                    tmp.append(i)
            idstr="|" + "|".join(tmp) + "|"
            if is_open_branch:
                output += child.printTree(req, treeobj, level+1, "block", idstr)
            else:
                output += child.printTree(req, treeobj, level+1, "none", idstr)
        if level == 0:
            return (u"""<TABLE border=0 width="100%%" cellpadding=0 cellspacing=0 class="table_tree"><tr><td colspan=3><img src="%sspacer.gif" width=1 height=15 border=0 alt=""></td></tr>\n""" % _Conf.BASE_ICON_URL)+ "\n".join(output) + "\n</TABLE>"
        else:
            return output
