"""

Document Object

$Id: _Document.py,v 1.4 2003/12/25 11:57:28 incxcvs Exp $
"""

import os, stat
import mx.DateTime

import _Utils, _Indexer, _Exceptions
import _InitTypes, _Conf, _Access
import _RootObject

BLOCK_SIZE = 65536

class Document(_RootObject.RootObject):
    table_name = 'documents'
    field_name = 'document_id'
    item_type_id = _InitTypes.ITEM_TYPE_DOCUMENT
    is_container = 0
    object_fields = {
'document_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 0,	 'has_default': 1,       'can_insert': 0 },
'filename':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'title':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'description':	{ 'type': _Utils.sql_cast_str_hidenull,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'comments':	{ 'type': _Utils.sql_cast_str_hidenull,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'author':	{ 'type': _Utils.sql_cast_str_hidenull,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'mime_major':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 1,       'can_insert': 1 },
'mime_minor':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 1,       'can_insert': 1 },
'final_version_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'doc_category':	{ 'type': _Utils.sql_cast_str_hidenull,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'locker_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'lock_due':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,	'can_insert': 1	},
    }

    fti_keys = ['filename','title','description','comments','author', 'doc_category']

    def __init__(self, REQUEST, init_type, extra_data=None): # Override for automatic lock expiration
        _RootObject.RootObject.__init__(self, REQUEST, init_type, extra_data)
        if self.get('locker_id') is not None and (self.get('lock_due') is None or self.get('lock_due') < _Utils.utc_now_mx()):
            self.set('locker_id', None)
            self.set('lock_due', None)
            self.REQUEST.su_by_id(_Conf.SUPERUSER)
            self.save()
            self.REQUEST.unsu()

    def get_name(self):
        if self.get('title') is not None:
            return self.get('title')
        elif self.get_id() is None:
            return self.REQUEST.TLS('docobj_notsaved')
        else:
            return self.REQUEST.TLS('docobj_noname') % self.get_id()

    def _get_path(self):
        if self.get_id() == _Conf.ROOTOBJECT:
            return _Conf.BASE_DOCUMENT_PATH
        elif self.get_parent_id() == _Conf.ROOTOBJECT:
            return os.path.join(_Conf.BASE_DOCUMENT_PATH, _Utils.make_path(self.get('filename')))
        else:
            return os.path.join(self.get_parent()._get_path(), _Utils.make_path(self.get('filename')))

    def get_size(self):
        return self.get('item_size') or 0

    def lock(self, lock_due_date, lock_due_time):
        if self.get('locker_id') is not None:
            raise RuntimeError, self.REQUEST.TLS('doc_alreadylocked')

        self.set('locker_id', self.REQUEST.USER.get_id())
        setattr(self, 'just_locked', 1)
        if lock_due_date.strip() and lock_due_time.strip():
            self.set('lock_due', self.REQUEST.user2isodatetime(self.REQUEST, '%s %s' % (lock_due_date, lock_due_time)))
        else:
            raise RuntimeError, self.REQUEST.TLS('doc_nolocktime')

    def unlock(self):
        if self.get('locker_id') is None:
            raise RuntimeError, self.REQUEST.TLS('doc_isnotlocked')

        locker = self.get('locker_id')
        if locker == self.REQUEST.USER.get_id() or _Access.get_item_right(self.REQUEST, self.get_id(), self.REQUEST.USER.get_id()) >= _Access.ACCESS_MANAGE:
            self.set('locker_id', None)
            self.set('lock_due', None)
        else:
            raise RuntimeError, self.REQUEST.TLS('doc_cantunlock')

    def AfterInsertHook(self):
        if self.REQUEST.form.has_key('filepointer'):
            filepointer = self.REQUEST.form['filepointer'].file
        else:
            filepointer = self.get('filepointer')
        if not filepointer:
            raise _Exceptions.DocumentError, self.REQUEST.TLS('docobj_nodocsave')

        if not self.get('filename'):
            raise _Exceptions.DocumentError, self.REQUEST.TLS('docobj_nodocsave')

        path = self.get_path()

#        if not self.get('index_this_item'):
#            _Indexer.index_file(self.REQUEST, filepointer, path, self.get_id())
        self.REQUEST.db.execute("""UPDATE items SET index_this_item=1 WHERE item_id=%d""" % self.get_id())

        fp = open(path.encode('UTF8'),'wb')

        fpwrite = fp.write
        fpread = filepointer.read

        data = fpread(BLOCK_SIZE)
        while data:
            fpwrite(data)
            data = fpread(BLOCK_SIZE)
        fp.close()

        self.__itemdata__['item_size'] = os.stat(path.encode('UTF8'))[stat.ST_SIZE]
        self.REQUEST.db.execute("UPDATE items SET item_size=%d WHERE item_id=%d" % (self.get_size(), self.get_id()))

    def AfterUpdateHook(self):
        if self.get('filepointer'):
            filepointer = self.get('filepointer')
            path = self.get_path()

            _Indexer.delete_index(self.REQUEST, self.get_id())
            _Indexer.index_file(self.REQUEST, filepointer, path, self.get_id())

            fp = open(path.encode('UTF8'),'wb')

            fpwrite = fp.write
            fpread = filepointer.read

            data = fpread(BLOCK_SIZE)
            while data:
                fpwrite(data)
                data = fpread(BLOCK_SIZE)
            fp.close()

            self.__itemdata__['item_size'] = os.stat(path.encode('UTF8'))[stat.ST_SIZE]
            self.REQUEST.db.execute("UPDATE items SET item_size=%d WHERE item_id=%d" % (self.get_size(), self.get_id()))

        self.rename_hook()

    def delete_hook(self):
        SQL = u"""SELECT d.document_id FROM items i, documents d WHERE d.document_id=i.item_id AND d.final_version_id=%d""" % self.get_id()
        self.REQUEST.db.execute(SQL.encode('UTF8'))
        versions = self.REQUEST.db.dictfetchall()
        for version in versions:
            ver = Document(self.REQUEST, _InitTypes.INIT_TYPE_ID, version['document_id'])
            ver.delete()

#        _Indexer.delete_index(self.REQUEST, self.get_id()) # This should be done by maintenance daemon
        oldpath = self.get_path()
        filename = "%d_%s" % (self.get_id(), os.path.split(oldpath)[1])
        newpath = os.path.join(self.make_backup_dir(), filename)
        if os.path.exists(oldpath.encode('UTF8')):
            os.rename(oldpath.encode('UTF8'), newpath.encode('UTF8'))
        else:
            fp = open(newpath.encode('UTF8'), 'wb') # FIXME
            fp.write("ERROR, MISSING FILE.\n")
            fp.close()
        self.set('oldpath', oldpath)

    def undelete_hook(self):
        delete_time = self.get('delete_time')
        newpath = self.get('oldpath')
        if delete_time is None or newpath is None:
            raise _Exceptions.DocumentError, self.REQUEST.TLS('docobj_undeletemissing')
        opj = os.path.join
        oldpath = opj(opj(opj(opj(_Conf.BACKUP_DOCUMENT_PATH, str(delete_time.year)), str(delete_time.month)), str(delete_time.day)), "%d_%s" % (self.get_id(), self.get('filename')))
        os.rename(oldpath.encode('UTF8'), newpath.encode('UTF8'))

    def rename_hook(self):
        if not self.__olddata__:
            self.REQUEST.db.execute("SELECT i.parent_id, d.filename FROM items i, documents d WHERE i.item_id=d.document_id AND item_id = %d" % self.get_id())
            r = self.REQUEST.db.dictfetchall()[0]
            old_filename = r['filename'].decode('UTF8')
            old_parent_id = r['parent_id']
        else:
            old_parent_id = self.__olddata__['parent_id']
            old_filename = self.__olddata__['filename'].decode('UTF8')
        if self.get_parent_id() == old_parent_id and self.get('filename') == old_filename:
            return

        oldpath = os.path.join(_RootObject.dispatch_item(self.REQUEST, old_parent_id).get_path(), _Utils.make_path(old_filename))
        os.rename(oldpath.encode('UTF8'), self.get_path().encode('UTF8'))

    def full_copyto(self, new_parent_id): # Overriding _RootObject method as we need to set a variable before save()
        old_path = self.get_path()
        new_obj = self.__class__(self.REQUEST, _InitTypes.INIT_TYPE_NEW)
        for (key, values) in self.item_fields.items():
            if values['can_set']:
                new_obj.set(key, self.get(key))
        for (key, values) in self.object_fields.items():
            if values['can_set']:
                new_obj.set(key, self.get(key))
        old_fp = open(old_path.encode('UTF8'), 'rb')
        new_obj.set('parent_id', new_parent_id)
        new_obj.set('filepointer', old_fp)
        if self.__itemdata__.has_key('copyto_replace_name'):
            new_obj.set('filename', self.get('copyto_replace_name'))
        newpath = new_obj.get_path()
        if os.path.exists(newpath.encode('UTF8')):
            new_obj.set('filename', _Utils.make_path("copy_%s" % os.path.split(newpath)[-1]))
        new_obj.save()
        if not old_fp.closed:
            old_fp.close()

        return new_obj

    def BeforeUpdateHook(self):
        if self.get('locker_id') is not None and not hasattr(self, 'just_locked'):
            raise RuntimeError, self.REQUEST.TLS('doc_islocked')

    def BeforeDeleteHook(self):
        if self.get('locker_id') is not None and not hasattr(self, 'just_locked'):
            raise RuntimeError, self.REQUEST.TLS('doc_islocked')
