"""

efolder Object

$Id: _Efolder.py,v 1.2 2003/12/12 21:13:48 incxcvs Exp $
"""

import _RootObject, _Utils
import _InitTypes

# _flags bits
EFOLDER_NONE = 0
EFOLDER_INBOX = 1
EFOLDER_SYSTEM = 2
EFOLDER_DELETED = 4
EFOLDER_DRAFTS = 8
EFOLDER_SENT = 16
EFOLDER_IMAPF = 32
EFOLDER_IMAPF_ACTIVE = 64
EFOLDER_SHARED = 128

class Efolder(_RootObject.RootObject):
    table_name = 'efolders'
    field_name = 'efolder_id'
    item_type_id = _InitTypes.ITEM_TYPE_EFOLDER
    is_container = 1
    object_fields = {
'efolder_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 0,	'has_default': 1,       'can_insert': 0 },
'efolder_name':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'efolder_flags':{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 1,	'has_default': 1,       'can_insert': 1 },
'eaccount_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
    }

    fti_keys = ['efolder_name']

    def get_name(self):
        if self.get('efolder_name') is not None:
            return self.get('efolder_name')
        elif self.get_id() is None:
            return self.REQUEST.TLS('efolderobj_notsaved')
        else:
            return self.REQUEST.TLS('efolder_noname') % self.get_id()

    def delete_hook(self): # delete all related efilters
        self.REQUEST.db.execute("""SELECT i.item_id FROM items i, email_filters f WHERE i.item_id=f.filter_id AND i.item_type_id=%d AND f.folder_id=%d""" %(_InitTypes.ITEM_TYPE_EFILTER, self.get_id()))
        res = self.REQUEST.db.dictfetchall()
        for efilter in res:
            obj = _Efilter.Efilter(self.REQUEST, _InitTypes.INIT_TYPE_ID, efilter['item_id'])
            obj.delete()

def create_default_folders(REQUEST):
    mbox = Efolder(REQUEST, _InitTypes.INIT_TYPE_NEW)
    mbox.set('parent_id', REQUEST.USER.get_id())
    mbox.set('is_private',1)
    mbox.set('efolder_name', 'Inbox')
    mbox.set('efolder_flags', EFOLDER_INBOX|EFOLDER_SYSTEM)
    mbox.save()

    mbox = Efolder(REQUEST, _InitTypes.INIT_TYPE_NEW)
    mbox.set('parent_id', REQUEST.USER.get_id())
    mbox.set('is_private',1)
    mbox.set('efolder_name', 'Sent Items')
    mbox.set('efolder_flags', EFOLDER_SYSTEM|EFOLDER_SENT)
    mbox.save()

    mbox = Efolder(REQUEST, _InitTypes.INIT_TYPE_NEW)
    mbox.set('parent_id', REQUEST.USER.get_id())
    mbox.set('is_private',1)
    mbox.set('efolder_name', 'Deleted Items')
    mbox.set('efolder_flags', EFOLDER_SYSTEM|EFOLDER_DELETED)
    mbox.save()

    mbox = Efolder(REQUEST, _InitTypes.INIT_TYPE_NEW)
    mbox.set('parent_id', REQUEST.USER.get_id())
    mbox.set('is_private',1)
    mbox.set('efolder_name', 'Drafts')
    mbox.set('efolder_flags', EFOLDER_SYSTEM|EFOLDER_DRAFTS)
    mbox.save()

def create_shared_folder(REQUEST):
    REQUEST.db.execute("""SELECT count(*) FROM items i, efolders e WHERE e.efolder_id=i.item_id AND i.parent_id=%d AND (efolder_flags & %d) <> 0""" % (REQUEST.USER.get_id(), EFOLDER_SHARED))
    if REQUEST.db.fetchone()[0]:
        return
    mbox = Efolder(REQUEST, _InitTypes.INIT_TYPE_NEW)
    mbox.set('parent_id', REQUEST.USER.get_id())
    mbox.set('is_private',1)
    mbox.set('efolder_name', 'Shared Folder')
    mbox.set('efolder_flags', EFOLDER_SHARED|EFOLDER_SYSTEM)
    mbox.save()

