"""

Folder Object

$Id: _Folder.py,v 1.3 2004/02/15 13:10:58 incxcvs Exp $
"""

import _RootObject, _Utils
import _InitTypes, _Exceptions

import os

class Folder(_RootObject.RootObject):
    table_name = 'folders'
    field_name = 'folder_id'
    item_type_id = _InitTypes.ITEM_TYPE_FOLDER
    is_container = 1
    object_fields = {
'folder_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 0,	 'has_default': 1,       'can_insert': 0 },
'folder_name':	{ 'type': _Utils.sql_cast_str,	'simple_type': str,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'comments':	{ 'type': _Utils.sql_cast_str_hidenull,	'simple_type': str,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 }
    }

    fti_keys = ['folder_name', 'comments']

    def get_name(self):
        if self.get('folder_name') is not None:
            return self.get('folder_name')
        elif self.get_id() is None:
            return self.REQUEST.TLS('folderobj_notsaved')
        else:
            return self.REQUEST.TLS('folderobj_noname') % self.get_id()

    def AfterInsertHook(self):
        path = self.get_path()
        os.mkdir(path.encode('UTF8'), 0755)

    def AfterUpdateHook(self):
        self.rename_hook()

    def delete_hook(self):
        oldpath = self.get_path()
        self.set('oldpath', oldpath)
        os.rmdir(oldpath.encode('UTF8'))

    def undelete_hook(self):
        oldpath = self.get('oldpath')
        if oldpath is None:
            raise _Exceptions.FolderError, self.REQUEST.TLS('folderobj_undeletemissing')
        os.mkdir(oldpath.encode('UTF8'))

    def rename_hook(self):
        if not self.__olddata__:
            self.REQUEST.db.execute("SELECT i.parent_id, f.folder_name FROM items i, folders f WHERE i.item_id=f.folder_id AND item_id = %d" % self.get_id())
            r = self.REQUEST.db.dictfetchall()[0]
            old_filename = r['folder_name'].decode('UTF8')
            old_parent_id = r['parent_id']
        else:
            old_parent_id = self.__olddata__['parent_id']
            old_filename = self.__olddata__['folder_name'].decode('UTF8')
        if self.get_parent_id() == old_parent_id and self.get('folder_name') == old_filename:
            return

        oldpath = os.path.join(_RootObject.dispatch_item(self.REQUEST, old_parent_id).get_path(), _Utils.make_path(old_filename))
        os.rename(oldpath.encode('UTF8'), self.get_path().encode('UTF8'))

    def full_copyto(self, new_parent_id): # DO NOT CALL DIRECTLY.
        new_obj = self.__class__(self.REQUEST, _InitTypes.INIT_TYPE_NEW)
        for (key, values) in self.item_fields.items():
            if values['can_set']:
                new_obj.set(key, self.get(key))
        for (key, values) in self.object_fields.items():
            if values['can_set']:
                new_obj.set(key, self.get(key))
        new_obj.set('parent_id', new_parent_id)
        if self.__itemdata__.has_key('copyto_replace_name'):
            new_obj.set('folder_name', self.get('copyto_replace_name'))
        if new_obj.copyto_hook: new_obj.copyto_hook() # This is supposed to check if stuff exists and then alter name
        new_obj.save()
        return new_obj

    def copyto_hook(self):
        newpath = self.get_path()
        if os.path.exists(newpath.encode('UTF8')):
            self.set('folder_name', _Utils.make_path("copy_%s" % os.path.split(newpath)[-1].encode('UTF8')))
