"""

Core Text Indexer

All content that needs to be indexed should be filtered through
required filters to achieve plain text and then fed to TextIndexer.

$Id: _Indexer.py,v 1.5 2004/02/15 13:10:58 incxcvs Exp $
"""

BLOCK_SIZE = 8192

import mimetypes, tempfile, popen2, os, unicodedata, cStringIO
from string import strip
import _Utils, _Conf, _Exceptions

tempfile.tempdir = _Conf.TEMP_DOCUMENT_PATH

def clean_garbage(character):
     if unicodedata.category(character)[0] in ['L','N']:
         return character
     else:
         return u" "

class TextIndexer:

    def __init__(self, REQUEST, fp, item_id, encoding=_Conf.ENCODING, ftitype='false'):
        self.REQUEST = REQUEST
        self.fp = fp
        self.item_id = item_id
        self.encoding = encoding
        self.ftitype = ftitype

    def index(self):
        FALLBACK_ENCODING = _Conf.FALLBACK_ENCODING
        words_dict = {}

        line = self.fp.readline()
        while line:
            try:
                line = "".join(map(clean_garbage, line.decode(self.encoding).lower()))
            except: # Let's try another encoding before failing.
                line = "".join(map(clean_garbage, line.decode(FALLBACK_ENCODING).lower()))
            words = map(strip, line.split(u" "))
            for word in words:
                wordlen = len(word)
                if wordlen < 3 or wordlen > 20:
                    continue
                elif wordlen == 3:
                    words_dict[word] = 1
                else:
                    for z in range(3, wordlen+1):
                        words_dict[word[:z]] = 1
            line = self.fp.readline()
        self.fp.seek(0)

        if words_dict:
            keys = words_dict.keys()
            for delta in range(0, len(keys),10):
                loop_words = keys[delta:delta+10]
                SQL = u"""SELECT word FROM fti_search WHERE (word = %s) AND fti_type=%s AND item_id=%d GROUP BY word""" % (" OR word=".join(map(lambda x: _Utils.sql_cast_str(self.REQUEST, x), loop_words)), self.ftitype, self.item_id)
                self.REQUEST.db.execute(SQL.encode('UTF8'))
                res = map(lambda x: x[0].decode('UTF8'), self.REQUEST.db.fetchall())
                for word in loop_words:
                    if word not in res:
                        SQL = u"""INSERT INTO fti_search (item_id, word, fti_type) VALUES (%d, %s, %s)""" % (self.item_id, _Utils.sql_cast_str(self.REQUEST, word), self.ftitype)
                        self.REQUEST.db.execute(SQL.encode('UTF8'))

class PDFIndexer(TextIndexer):
    parser = _Conf.PARSER_PDF

    def index(self):
        if not os.path.exists(self.parser):
            raise _Exceptions.IndexerError, self.REQUEST.TLS('indexer_noparser') % 'PDF'

        tmpname = tempfile.mktemp()
        newname = tempfile.mktemp()

        tmpfp = open(tmpname,'wb')
            
        fpwrite = tmpfp.write
        fpread = self.fp.read
            
        data = fpread(BLOCK_SIZE)
        while data:
            fpwrite(data)
            data = fpread(BLOCK_SIZE)
        tmpfp.close()
        self.fp.seek(0)
        tmpfp = self.fp

        res = popen2.Popen4("%s -enc UTF-8 %s %s" % (self.parser, tmpname, newname))
        if res.wait():
            try:
                os.unlink(tmpname)
                os.unlink(newname)
            except:
                pass
            raise _Exceptions.IndexerError, self.REQUEST.TLS('indexer_failed') % (res, 0) # FIXME
        self.fp = open(newname,'rb')
        TextIndexer.index(self)
        self.fp.close()
        try:
            os.unlink(newname)
            os.unlink(tmpname)
        except:
            pass
        self.fp = tmpfp

class WordIndexer(TextIndexer):
    parser = _Conf.PARSER_DOC

    def index(self):
        if not os.path.exists(self.parser):
            raise _Exceptions.IndexerError, self.REQUEST.TLS('indexer_noparser') % 'Microsoft Word'

        tmpname = tempfile.mktemp()
        newname = tempfile.mktemp()

        tmpfp = open(tmpname,'wb')
            
        fpwrite = tmpfp.write
        fpread = self.fp.read
            
        data = fpread(BLOCK_SIZE)
        while data:
            fpwrite(data)
            data = fpread(BLOCK_SIZE)
        tmpfp.close()
        self.fp.seek(0)
        tmpfp = self.fp

        res = popen2.Popen4("%s %s --targetdir=%s %s" % (self.parser, tmpname, os.path.split(newname)[0], os.path.split(newname)[1]))
        if res.wait():
            try:
                os.unlink(tmpname)
                os.unlink(newname)
            except:
                pass
            raise _Exceptions.IndexerError, self.REQUEST.TLS('indexer_failed') % (res, 0) # FIXME
        self.fp = open(newname,'rb')
        data = self.fp.read()
        self.fp.close()
        self.fp = cStringIO.StringIO(_Utils.strip_html(data,valid_tags=[]))
        del data
        self.fp.seek(0)
        TextIndexer.index(self)
        self.fp.close()
        self.fp = tmpfp
        try:
            os.unlink(newname)
            os.unlink(tmpname)
        except:
            pass

class HTMLIndexer(TextIndexer):
    def index(self):
        tmpfp = cStringIO.StringIO(_Utils.strip_html(self.fp.read(),valid_tags=[]))

        tmpfp.seek(0)
        self.fp.seek(0)
        tmp2 = self.fp
        self.fp = tmpfp
        TextIndexer.index(self)
        self.fp.close()
        self.fp = tmp2
       

indexers = {
'text/plain': TextIndexer,
'application/msword': WordIndexer,
'application/pdf':PDFIndexer,
'text/html':HTMLIndexer,
}

def index_file(REQUEST, fp, filename, item_id, encoding=_Conf.ENCODING, ftitype='false'):
    ftype, fileencoding = mimetypes.guess_type(filename)
    if ftype is None or not indexers.has_key(ftype): # We don't know the type, thus we do not know whether we should index it.
        return

    indexer = indexers[ftype](REQUEST, fp, item_id, encoding, ftitype)
    indexer.index()

def delete_index(REQUEST, item_id, ftitype='false'):
    REQUEST.db.execute("""\
DELETE FROM fti_search
WHERE
  item_id=%d and fti_type=%s""" % (item_id, ftitype))
