 # $Id: _Publisher.py,v 1.10 2004/02/18 11:30:36 incxcvs Exp $
 #
 # ====================================================================
 # The Apache Software License, Version 1.1
 #
 # Copyright (c) 2000-2002 The Apache Software Foundation.  All rights
 # reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
 # are met:
 #
 # 1. Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
 #
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in
 #    the documentation and/or other materials provided with the
 #    distribution.
 #
 # 3. The end-user documentation included with the redistribution,
 #    if any, must include the following acknowledgment:
 #       "This product includes software developed by the
 #        Apache Software Foundation (http://www.apache.org/)."
 #    Alternately, this acknowledgment may appear in the software itself,
 #    if and wherever such third-party acknowledgments normally appear.
 #
 # 4. The names "Apache" and "Apache Software Foundation" must
 #    not be used to endorse or promote products derived from this
 #    software without prior written permission. For written
 #    permission, please contact apache@apache.org.
 #
 # 5. Products derived from this software may not be called "Apache",
 #    "mod_python", or "modpython", nor may these terms appear in their
 #    name, without prior written permission of the Apache Software
 #    Foundation.
 #
 # THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 # WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 # OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 # DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 # ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 # SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 # LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 # USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 # ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 # OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 # ====================================================================
 #
 # This software consists of voluntary contributions made by many
 # individuals on behalf of the Apache Software Foundation.  For more
 # information on the Apache Software Foundation, please see
 # <http://www.apache.org/>.
 #
 # Originally developed by Gregory Trubetskoy.
 #

"""
  This handler is conceputally similar to Zope's ZPublisher, except
  that it:

  1. Is written specifically for mod_python and is therefore much faster
  2. Does not require objects to have a documentation string
  3. Passes all arguments as simply string
  4. Does not try to match Python errors to HTTP errors
  5. Does not give special meaning to '.' and '..'.
"""

from mod_python import apache
from mod_python import util
import _apache

import os
import imp
import re
import base64

import _Conf

try:
    from mod_python import Cookie
    _Conf.IS_MP_31 = 1
except ImportError:
    pass

import sys, traceback, cStringIO, cgi, quopri, time
import _Exceptions, _Utils
try:
    import _Baselib
except: # Probably a database connection issue, let's fail until apache restart
    _Baselib = None
import translator, standard_html
    

def get_tb():
    tbfp = cStringIO.StringIO()
    traceback.print_exc(file=tbfp)
    tbfp.seek(0)
    TB = tbfp.read()
    tbfp.close()
    try:
        return TB.decode('UTF8')
    except:
        return quopri.encodestring(TB)

def handler(req):
    req.allow_methods(["GET", "POST", "OPTIONS", "HEAD"])
    if req.method not in ["GET", "POST", "OPTIONS", "HEAD"]:
        raise apache.SERVER_RETURN, apache.HTTP_METHOD_NOT_ALLOWED

    if req.method in ["OPTIONS"]:
        ALLOWED_METHODS = ["GET", "POST", "PROPFIND", "OPTIONS", "HEAD", "COPY", "MOVE", "PUT", "MKCOL", "DELETE"]
        req.headers_out.add("Allow", ", ".join(ALLOWED_METHODS))
        req.headers_out.add("DAV", "1")
        req.headers_out.add("MS-Author-Via", "DAV")
        return apache.OK

    req.headers_out.add("Pragma", "no-cache")
    req.content_type = "text/html; charset=UTF-8"

    func_path = ""
    if req.path_info:
        func_path = req.path_info[1:] # skip first /
        func_path = func_path.replace("/", ".")
        if func_path[-1:] == ".":
            func_path = func_path[:-1] 

    # default to 'index' if no path_info was given
    if not func_path:
        func_path = "index"

    # if any part of the path begins with "_", abort
    if func_path[0] == '_' or func_path.count("._"):
        raise apache.SERVER_RETURN, apache.HTTP_NOT_FOUND

    # process input, if any
    fs = util.FieldStorage(req, keep_blank_values=1)
    req.form = fs

    # Before we start calling stuff, let's prepare our REQUEST and SESSION
    # Mod_python does 'args["req"] = req' by default, we don't want that request, we want ours.
    # This can throw PleaseAuthenticate exception, then we show the login screen.
    if _Baselib and not hasattr(_Baselib, 'Request'):
        reload(_Baselib)
    try:
        REQUEST = _Baselib.Request(req)
    except _Exceptions.SystemExpired, msg:
        req.headers_out.add("Set-Cookie", "RealmAuthCookie=2; Path=%s; Expires=Mon, 01-Jan-1990 00:00:00 GMT" % _Conf.BASE_URL)
        ns = {'BASE_ICON_URL':_Conf.BASE_ICON_URL}
        ns['URL'] = ''
        ns['BASE_URL'] = _Conf.BASE_URL
        ns['BASE_WEB_URL'] = _Conf.BASE_WEB_URL
        ns['formkeys'] = ""
        ns['reason'] = msg
        ns['app_name'] = _Conf.APP_NAME

        formresult = _Conf.EXPIRED_FORM % ns
        req.write(formresult.encode('UTF8'))
        return apache.OK
    except RuntimeError:
        ns = {'BASE_ICON_URL':_Conf.BASE_ICON_URL}
        if req.uri[-9:] == '/index.py':
            ns['URL'] = req.uri[:-8]
        else:
            ns['URL'] = req.uri
        ns['BASE_URL'] = _Conf.BASE_URL
        ns['BASE_WEB_URL'] = _Conf.BASE_WEB_URL
        if req.form.keys():
            formkeys = []
            for key in req.form.keys():
                if key not in ['RealmAuthUser', 'RealmAuthPass', 'x', 'y']:
                    formkeys.append(u"""<INPUT type="hidden" name="%s" value="%s">""" % (key, req.form[key].value.decode('UTF8')))
            ns['formkeys'] = "\n".join(formkeys)
        else:
            ns['formkeys'] = ""
        ns['reason'] = 'Database connection failure' # FIXME translate

        ns['news'] = ""

        dummy = Dummy()
        tls = translator.Translator(dummy)
        ns['tls_user'] = tls.translate('login_user')          
        ns['tls_password'] = tls.translate('login_password')
        ns['tls_remember'] = tls.translate('login_remember')
        ns['app_name'] = _Conf.APP_NAME
        del tls
        del dummy

        formresult = _Conf.LOGIN_FORM % ns
        req.write(formresult.encode('UTF8'))
        return apache.OK
    except AttributeError:
        ns = {'BASE_ICON_URL':_Conf.BASE_ICON_URL}
        if req.uri[-9:] == '/index.py':
            ns['URL'] = req.uri[:-8]
        else:
            ns['URL'] = req.uri
        ns['BASE_URL'] = _Conf.BASE_URL
        ns['BASE_WEB_URL'] = _Conf.BASE_WEB_URL
        if req.form.keys():
            formkeys = []
            for key in req.form.keys():
                if key not in ['RealmAuthUser', 'RealmAuthPass', 'x', 'y']:
                    formkeys.append(u"""<INPUT type="hidden" name="%s" value="%s">""" % (key, req.form[key].value.decode('UTF8')))
            ns['formkeys'] = "\n".join(formkeys)
        else:
            ns['formkeys'] = ""
        ns['reason'] = 'Database connection failure' # FIXME translate

        ns['news'] = ""

        dummy = Dummy()
        tls = translator.Translator(dummy)
        ns['tls_user'] = tls.translate('login_user')          
        ns['tls_password'] = tls.translate('login_password')
        ns['tls_remember'] = tls.translate('login_remember')
        ns['app_name'] = _Conf.APP_NAME
        del tls
        del dummy

        formresult = _Conf.LOGIN_FORM % ns
        req.write(formresult.encode('UTF8'))
        return apache.OK
    except _Exceptions.PleaseAuthenticate:
        if req.uri == _Conf.BASE_URL + 'logout.py':
            req.headers_out.add("Set-Cookie", "RealmAuthCookie=2; Path=%s; Expires=Mon, 01-Jan-1990 00:00:00 GMT" % _Conf.BASE_URL)
            ns = {}
            ns['BASE_URL'] = _Conf.BASE_URL
            ns['BASE_WEB_URL'] = _Conf.BASE_WEB_URL
            ns['BASE_ICON_URL'] = _Conf.BASE_ICON_URL
            ns['app_name'] = _Conf.APP_NAME
            req.write(_Conf.LOGOUT_MESSAGE % ns)
            return apache.OK

        req.headers_out.add("Set-Cookie", "RealmAuthCookie=2; Path=%s; Expires=Mon, 01-Jan-1990 00:00:00 GMT" % _Conf.BASE_URL)
        ns = {'BASE_ICON_URL':_Conf.BASE_ICON_URL}
        if req.uri[-9:] == '/index.py':
            ns['URL'] = req.uri[:-8]
        else:
            ns['URL'] = req.uri
        ns['BASE_URL'] = _Conf.BASE_URL
        ns['BASE_WEB_URL'] = _Conf.BASE_WEB_URL
        if req.form.keys():
            formkeys = []
            for key in req.form.keys():
                if key not in ['RealmAuthUser', 'RealmAuthPass', 'x', 'y']:
                    formkeys.append(u"""<INPUT type="hidden" name="%s" value="%s">""" % (key, req.form[key].value.decode('UTF8')))
            ns['formkeys'] = "\n".join(formkeys)
        else:
            ns['formkeys'] = ""
        try:
            ns['reason'] = str(sys.exc_value)
        except:
            ns['reason'] = 'Login'

        con = None
        try: # Get a db connection and 
            import _DBSpool
            con = _DBSpool.DBSpool.get_connection()

            con.execute("SELECT * FROM systemnotes ORDER BY note_stamp DESC")
            dbresult = con.dictfetchall()
            ns['news'] = []
            for result in dbresult:
                ns['news'].append(u"""%s""" % (_Utils.newline2br(result['note_message'].decode('UTF8'))))
            if ns['news']:
                ns['news'] = "<BR><BR>".join(ns['news'])
            else:
                ns['news'] = ""
            con.commit()
        except:
            ns['news'] = ""
        if con:
            con.commit()
            con.close()
        del con
        dummy = Dummy()
        tls = translator.Translator(dummy)
        ns['tls_user'] = tls.translate('login_user')          
        ns['tls_password'] = tls.translate('login_password')
        ns['tls_remember'] = tls.translate('login_remember')
        ns['app_name'] = _Conf.APP_NAME
        del tls
        del dummy

        formresult = _Conf.LOGIN_FORM % ns
        req.write(formresult.encode('UTF8'))
        return apache.OK

    args = {}
    args["REQUEST"] = REQUEST

    # We've got to main-line try/except this to prevent very rare corruptions
    try:
        ## import the script
        path, module_name =  os.path.split(req.filename)
        if not module_name:
            module_name = "index"
        if module_name[-3:].lower()==".py" and module_name[:-3].isdigit():
            output = []
            output.append(standard_html.html_header_popup(REQUEST))
            output.append(standard_html.standard_redirect(REQUEST, "%sindex.py?ext_link2=%d" % (_Conf.BASE_URL, int(module_name[:-3])), 0))
            output.append(standard_html.html_footer3(REQUEST))
            output = "\n".join(output)
            req.write(output.encode('UTF8'))
            REQUEST.db.commit()
            REQUEST.close()
            return apache.OK

        # get rid of the suffix
        #   explanation: Suffixes that will get stripped off
        #   are those that were specified as an argument to the
        #   AddHandler directive. Everything else will be considered
        #   a package.module rather than module.suffix
        exts = req.get_addhandler_exts()
        if exts:
            suffixes = exts.strip().split()
            exp = "\\." + "$|\\.".join(suffixes)
            suff_matcher = re.compile(exp) # python caches these, so its fast
            module_name = suff_matcher.sub("", module_name)

        # import module (or reload if needed)
        # the [path] argument tells import_module not to allow modules whose
        # full path is not in [path] or below.
        if _Conf.IS_MP_31:
            module = apache.import_module(module_name, autoreload=1, log=0, path=[path])
        else:
            module = apache.import_module(module_name, req.get_config(), [path])

        # does it have an __auth__?
        realm, user, passwd = process_auth(req, module)

        # resolve the object ('traverse')
        try:
            object = resolve_object(req, module, func_path, realm, user, passwd)
        except AttributeError:
            raise apache.SERVER_RETURN, apache.HTTP_NOT_FOUND

        # not callable, a class or an aunbound method
        if not callable(object) or \
           str(type(object)) == "<type 'class'>" \
           or (hasattr(object, 'im_self') and not object.im_self):
            result = str(object)
        else:
            # callable, (but not a class or unbound method)

            # we need to weed out unexpected keyword arguments
            # and for that we need to get a list of them. There
            # are a few options for callable objects here:

            if str(type(object)) == "<type 'instance'>":
                # instances are callable when they have __call__()
                object = object.__call__

            if hasattr(object, "func_code"):
                # function
                fc = object.func_code
                expected = fc.co_varnames[0:fc.co_argcount]
            elif hasattr(object, 'im_func'):
                # method
                fc = object.im_func.func_code
                expected = fc.co_varnames[1:fc.co_argcount]

            # remove unexpected args unless co_flags & 0x08,
            # meaning function accepts **kw syntax
            if not (fc.co_flags & 0x08):
                for name in args.keys():
                    if name not in expected:
                        del args[name]

        result = apply(object, (), args)
        REQUEST.db.commit() # Commit changes
    except apache.SERVER_RETURN:
        REQUEST.db.rollback() # Rollback any changes
        REQUEST.close()
        raise
    except:
        REQUEST.db.rollback() # Rollback any changes
        ns = {}
        ns['BASE_WEB_URL'] = unicode(_Conf.BASE_WEB_URL)
        ns['BASE_ICON_URL'] = unicode(_Conf.BASE_ICON_URL)
        ns['tls_error'] = unicode(REQUEST.TLS('system_erroroccured'))
        ns['tls_back'] = unicode(REQUEST.TLS('system_back'))
        try: # We need to load this before sending mail, or the message will be incorrect.
            errorobj = sys.exc_value.args[0]
            sys_exc_value_args = sys.exc_value.args
        except:
            pass
        if _Conf.ERROR_SHOW_TB:
            try:
                TB = get_tb()
                TB += '\nUser: %d' % REQUEST.USER.get_id()
                TB += '\nURL: %s' % quopri.encodestring(req.unparsed_uri)
                TB += '\nGMTime: %s' % _Utils.utc_now_mx()
                TB += '\nIP: %s' % req.connection.remote_ip
                if _Conf.ERROR_EMAIL_ADMIN:
                    try:
                        import smtplib
                        server = smtplib.SMTP(_Conf.SMTPSERVER)
                        server.sendmail('conflux@%s' % _Conf.SMTPSERVER, _Conf.ERROR_EMAIL_ADMIN, TB)
                        server.quit()
                        ns['TB'] = cgi.escape(TB) + '\nSent mail.'
                    except:
                        ns['TB'] = cgi.escape(TB) + '\nFailed to send mail.'
                else:
                    ns['TB'] = cgi.escape(TB) + '\nSending mail not configured.'
            except:
                ns['TB'] = 'Could not retrieve TB.'
        else:
            ns['TB'] = 'Error reporting is disabled.'
        try:
            if isinstance(errorobj, unicode):
                ns['error_msg'] = _Utils.newline2br(errorobj)
            elif isinstance(errorobj, str):
                try:
                    ns['error_msg'] = _Utils.newline2br(errorobj.decode('UTF8'))
                except:
                    ns['error_msg'] = _Utils.newline2br(errorobj.decode(_Conf.FALLBACK_ENCODING))
            else:
                ns['error_msg'] = ", ".join(map(str, sys_exc_value_args))
                try:
                    ns['error_msg'] = ns['error_msg'].decode('UTF8')
                except:
                    ns['error_msg'] = ns['error_msg'].decode(_Conf.FALLBACK_ENCODING)
        except:
            ns['error_msg'] = ''
        ns['app_name'] = _Conf.APP_NAME
        result = _Conf.ERROR_MESSAGE % ns

    REQUEST.close()

    if isinstance(result, int):
        return result
    elif result:
        if isinstance(result, unicode):
            result = result.encode("UTF8")
#        else:
#            raise RuntimeError, 'str-result returned to publisher (%s).' % req.filename # FIXME

        if req.method != "HEAD":
            req.write(result)
        else:
            req.write("")
#        req.write("""Request took: %s seconds.""" % (time.time() - req.request_time))
        return apache.OK
    else:
        return apache.HTTP_INTERNAL_SERVER_ERROR

def process_auth(req, object, realm="unknown", user=None, passwd=None):
    return realm, user, passwd

def resolve_object(req, obj, object_str, realm=None, user=None, passwd=None):
    """
    This function traverses the objects separated by .
    (period) to find the last one we're looking for.
    """

    for obj_str in  object_str.split('.'):
        obj = getattr(obj, obj_str)

        # object cannot be a module
        if type(obj) == type(apache):
            raise apache.SERVER_RETURN, apache.HTTP_NOTFOUND

        realm, user, passwd = process_auth(req, obj, realm,
                                           user, passwd)

    return obj


class File:
    """ Like a file, but also has headers and filename
    """

    def __init__(self, field):

        # steal all the file-like methods
        for m in dir(field.file):
            self.__dict__[m] = getattr(field.file, m)

        self.headers = field.headers
        self.filename = field.filename

class Dummy:
    pass
