"""

_Resource Object

$Id: _Resource.py,v 1.5 2004/02/15 13:10:58 incxcvs Exp $
"""

import _RootObject, _Utils
import _InitTypes, _Conf, _Event, _Access

import os

class Resource(_RootObject.RootObject):
    table_name = 'resources'
    field_name = 'resource_id'
    item_type_id = _InitTypes.ITEM_TYPE_RESOURCE
    is_container = 0
    object_fields = {
'resource_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 0,	 'has_default': 1,       'can_insert': 0 },
'resource_name':	{ 'type': _Utils.sql_cast_str,	'simple_type': str,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
    }

    fti_keys = ['resource_name']

    def get_name(self):
        if self.get('resource_name') is not None:
            return self.get('resource_name')
        elif self.get_id() is None:
            return self.REQUEST.TLS('resourceobj_notsaved')
        else:
            return self.REQUEST.TLS('resourceobj_noname') % self.get_id()

    def add_to_event(self, event_id):
        QUERY = """INSERT INTO event_resources ( event_id, resource_id ) VALUES ( %d, %d )""" % (event_id, self.get_id())
        self.REQUEST.db.execute(QUERY)

    def del_from_event(self, event_id):
        QUERY = """DELETE FROM event_resources WHERE event_id=%d AND resource_id=%d""" % (event_id, self.get_id())
        self.REQUEST.db.execute(QUERY)

def get_event_resources(REQUEST, event_id):
    QUERY = """SELECT resource_id FROM event_resources WHERE event_id=%d""" % event_id
    REQUEST.db.execute(QUERY)
    dbresult = REQUEST.db.dictfetchall()
    output = []
    REQUEST.disable_permissions = _Access.ACCESS_READ
    for row in dbresult:
        output.append(Resource(REQUEST, _InitTypes.INIT_TYPE_ID, row['resource_id']))
    del REQUEST.disable_permissions
    return output

def get_event_resource_ids(REQUEST, event_id):
    QUERY = """SELECT resource_id FROM event_resources WHERE event_id=%d""" % event_id
    REQUEST.db.execute(QUERY)
    dbresult = REQUEST.db.dictfetchall()
    output = []
    for row in dbresult:
        output.append(row['resource_id'])
    return output

def get_list_event_resource_ids(REQUEST, event_ids):
    if not event_ids: return {}
    QUERY = """SELECT resource_id, event_id FROM event_resources WHERE event_id in (%s)""" % ",".join(map(str, event_ids))
    REQUEST.db.execute(QUERY)
    dbresult = REQUEST.db.dictfetchall()
    output = {}
    for row in dbresult:
        try:
            output[row['event_id']].append(row['resource_id'])
        except KeyError:
            output[row['event_id']] = [row['resource_id']]
    return output

def get_resource_events(REQUEST, resource_id):
    QUERY = """SELECT event_id FROM event_resources WHERE resource_id=%d""" % resource_id
    REQUEST.db.execute(QUERY)
    dbresult = REQUEST.db.dictfetchall()
    output = []
    REQUEST.su_by_id(_Conf.SUPERUSER)
    for row in dbresult:
        output.append(_Event.Event(REQUEST, _InitTypes.INIT_TYPE_ID, row['event_id']))
    REQUEST.unsu()
    return output

def remove_event_resources(REQUEST, event_id):
    QUERY = """DELETE FROM event_resources WHERE event_id=%d""" % event_id
    REQUEST.db.execute(QUERY)

def check_for_conflicts(REQUEST, event):
    output = []
    resources = get_event_resources(REQUEST, event.get_id())
    for resource in resources:
        events = get_resource_events(REQUEST, resource.get_id())
        for res_event in events:
            if res_event.get_id() == event.get_id():
                continue
            # 1-st condition: start time in other event time
            # 2-nd condition: end time in other event time
            # 3-rd condition: main event contains other event
            if (event.get('start_stamp') >= res_event.get('start_stamp') and \
                event.get('start_stamp') <= res_event.get('end_stamp')) or \
               (event.get('end_stamp') >= res_event.get('start_stamp') and \
                event.get('end_stamp') <= res_event.get('end_stamp')) or \
               (event.get('start_stamp') <= res_event.get('start_stamp') and \
                event.get('end_stamp') >= res_event.get('end_stamp')):
                output.append((resource, res_event))
    return output
