"""

Translation Object

"""

import os, stat, time
import mx.DateTime

import _Utils, _Exceptions, _DusConf
import _InitTypes, _Conf
import _RootObject

BLOCK_SIZE = 65536

class Translation(_RootObject.RootObject):
    table_name = 'dus_translations'
    field_name = 'translation_id'
    item_type_id = _InitTypes.ITEM_TYPE_DUSTRANSLATION
    is_container = 0
    object_fields = {
'translation_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 0,	 'has_default': 1,       'can_insert': 0 },
'filename':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
    }

    fti_keys = ['filename']

    def get_name(self):
        if self.get('filename') is not None:
            return self.get('filename')
        elif self.get_id() is None:
            return self.REQUEST.TLS('docobj_notsaved')
        else:
            return self.REQUEST.TLS('docobj_noname') % self.get_id()

    def _get_path(self):
       return os.path.join(self.make_file_dir(), "%s_%s" % (self.get_id(), _Utils.make_path(self.get('filename'))))

    def get_size(self):
        return self.get('item_size') or 0

    def AfterInsertHook(self):
        if self.REQUEST.form.has_key('filepointer'):
            filepointer = self.REQUEST.form['filepointer'].file
        else:
            filepointer = self.get('filepointer')
        if not filepointer:
            raise _Exceptions.DocumentError, self.REQUEST.TLS('docobj_nodocsave')

        if not self.get('filename'):
            raise _Exceptions.DocumentError, self.REQUEST.TLS('docobj_nodocsave')

        path = self.get_path()

        fp = open(path.encode('UTF8'),'wb')

        fpwrite = fp.write
        fpread = filepointer.read

        data = fpread(BLOCK_SIZE)
        while data:
            fpwrite(data)
            data = fpread(BLOCK_SIZE)
        fp.close()

        self.__itemdata__['item_size'] = os.stat(path.encode('UTF8'))[stat.ST_SIZE]
        self.REQUEST.db.execute("UPDATE items SET item_size=%d WHERE item_id=%d" % (self.get_size(), self.get_id()))

    def AfterUpdateHook(self):
        if self.get('filepointer'):
            filepointer = self.get('filepointer')
            path = self.get_path()

            fp = open(path.encode('UTF8'),'wb')

            fpwrite = fp.write
            fpread = filepointer.read

            data = fpread(BLOCK_SIZE)
            while data:
                fpwrite(data)
                data = fpread(BLOCK_SIZE)
            fp.close()

            self.__itemdata__['item_size'] = os.stat(path.encode('UTF8'))[stat.ST_SIZE]
            self.REQUEST.db.execute("UPDATE items SET item_size=%d WHERE item_id=%d" % (self.get_size(), self.get_id()))

        self.rename_hook()

    def delete_hook(self):
        SQL = u"""SELECT d.document_id FROM items i, documents d WHERE d.document_id=i.item_id AND d.final_version_id=%d""" % self.get_id()
        self.REQUEST.db.execute(SQL.encode('UTF8'))
        versions = self.REQUEST.db.dictfetchall()
        for version in versions:
            ver = Document(self.REQUEST, _InitTypes.INIT_TYPE_ID, version['document_id'])
            ver.delete()

        oldpath = self.get_path()
        filename = "%d_%s" % (self.get_id(), os.path.split(oldpath)[1])
        newpath = os.path.join(self.make_backup_dir(), filename)
        if os.path.exists(oldpath.encode('UTF8')):
            os.rename(oldpath.encode('UTF8'), newpath.encode('UTF8'))
        else:
            fp = open(newpath.encode('UTF8'), 'wb') # FIXME
            fp.write("ERROR, MISSING FILE.\n")
            fp.close()
        self.set('oldpath', oldpath)

    def undelete_hook(self):
        delete_time = self.get('delete_time')
        newpath = self.get('oldpath')
        if delete_time is None or newpath is None:
            raise _Exceptions.DocumentError, self.REQUEST.TLS('docobj_undeletemissing')
        opj = os.path.join
        oldpath = opj(opj(opj(opj(_Conf.BACKUP_DOCUMENT_PATH, str(delete_time.year)), str(delete_time.month)), str(delete_time.day)), "%d_%s" % (self.get_id(), self.get('filename')))
        os.rename(oldpath.encode('UTF8'), newpath.encode('UTF8'))

    def make_file_dir(self):
        now = self.get('create_time')
        if now is None:
            now = mx.DateTime.now().gmtime()
        folder = os.path.join(_DusConf.BASE_TRANSLATION_PATH, os.path.join(os.path.join(str(now.year), str(now.month)), str(now.day)))
        if not os.path.exists(folder):
            os.makedirs(folder)
        return folder
