"""

Workflow Object

$Id: _Workflow.py,v 1.6 2004/02/15 13:10:58 incxcvs Exp $
"""

import smtplib, urllib, email.MIMEText, email.Header
import _RootObject, _Utils
import _InitTypes, _Conf

# _flags bits
WORKFLOW_SERIAL = 1
WORKFLOW_INIT_EMAIL = 2
WORKFLOW_COMPL_EMAIL = 4

class Workflow(_RootObject.RootObject):
    table_name = 'workflows'
    field_name = 'workflow_id'
    item_type_id = _InitTypes.ITEM_TYPE_WORKFLOW
    is_container = 1
    object_fields = {
'workflow_id':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 0,	'has_default': 1,       'can_insert': 0 },
'workflow_title':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'workflow_start_time':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 0,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'workflow_due_time':	{ 'type': _Utils.sql_cast_str,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'workflow_description':	{ 'type': _Utils.sql_cast_str_hidenull,	'simple_type': unicode,	'null': 1,	'can_set': 1,	'has_default': 0,       'can_insert': 1 },
'workflow_flags':{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 1,	'has_default': 1,       'can_insert': 1 },
'related_persons': { 'type': _Utils.sql_cast_array, 'simple_type': list, 'null': 0, 'can_set': 1, 'has_default': 1, 'can_insert': 1 },
'percent_complete':	{ 'type': _Utils.sql_cast_int,	'simple_type': int,	'null': 0,	'can_set': 1,	'has_default': 1,       'can_insert': 1 },
    }

    fti_keys = ['workflow_title','workflow_description']

    def get_name(self):
        if self.get('workflow_title') is not None:
            return self.get('workflow_title')
        elif self.get_id() is None:
            return self.REQUEST.TLS('workflowobj_notsaved')
        else:
            return self.REQUEST.TLS('workflowobj_noname') % self.get_id()

    def AfterInsertHook(self):
        if self.get('workflow_flags') & WORKFLOW_INIT_EMAIL:
            self.__olddata__ = {}
            self.load_db(self.get_id())
            self.send_workflow_init()

    def refresh_complete(self):
        SQL = "SELECT percent_complete FROM todos where workflow_id=%d" % self.get_id()
        self.REQUEST.db.execute(SQL)
        res = self.REQUEST.db.fetchall()
        if not res:
            return
        else:
            a=sum(map(lambda x:x[0],res))/len(res)
            SQL = "UPDATE workflows set percent_complete=%d where workflow_id=%d" % (a, self.get_id())
            self.REQUEST.db.execute(SQL)
            self.set('percent_complete', a)

    def send_workflow_init(self):
        subject = self.REQUEST.TLS('wfreminder_init_subject') % self.get('workflow_title')
        wf2 = {}
        for key in self.object_fields.keys():
            wf2[key] = self.get(key)
            if wf2[key] is None:
                wf2[key] = ''
            elif key in ['workflow_due_time', 'workflow_start_time'] and wf2[key]:
                wf2[key] = self.REQUEST.iso2userdate(wf2[key])
            elif key in ['workflow_due_time', 'workflow_start_time']:
                wf2[key] = ''
        if self.REQUEST.is_https:
            wf2['conflux_url'] = 'https://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, self.get_id())
        else:
            wf2['conflux_url'] = 'http://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, self.get_id())
        message = self.REQUEST.TLS('wfreminder_init_message') % wf2

        msg = email.MIMEText.MIMEText(message.encode('UTF8'))
        del msg['Content-Type']
        msg['Content-Type'] = 'text/plain; charset="utf-8"'
        msg['From'] = str(email.Header.Header(u'%s <%s@%s>' % (_Conf.APP_NAME, _Conf.APP_EMAIL_NAME, _Conf.SMTPSERVER)))
        to = []
        if self.REQUEST.USER.get_person(self.REQUEST).get('e_mail'):
            to.append(str(email.Header.Header(self.REQUEST.USER.get_person(self.REQUEST).get('e_mail'))))
            msg['To'] = to[-1]
        for relid in _Utils.sql_parse_array(self.REQUEST, self.get('related_persons')):
            p = _RootObject.dispatch_item(self.REQUEST, relid)
            if p.get('e_mail'):
                to.append(str(email.Header.Header(p.get('e_mail'))))
                msg['To'] = to[-1]
        msg['Subject'] = str(email.Header.Header(subject))

        try:        
            server = smtplib.SMTP(_Conf.SMTPSERVER)
            server.sendmail(str(msg['from']), to, msg.as_string())
            server.quit()
        except:
            pass

    def send_workflow_complete(self):
        if not self.get('workflow_flags') & WORKFLOW_COMPL_EMAIL:
            return

        subject = self.REQUEST.TLS('wfreminder_complete_subject') % self.get('workflow_title')
        wf2 = {}
        for key in self.object_fields.keys():
            wf2[key] = self.get(key)
            if wf2[key] is None:
                wf2[key] = ''
            elif key in ['workflow_due_time', 'workflow_start_time'] and wf2[key]:
                wf2[key] = self.REQUEST.iso2userdate(wf2[key])
            elif key in ['workflow_due_time', 'workflow_start_time']:
                wf2[key] = ''
        if self.REQUEST.is_https:
            wf2['conflux_url'] = 'https://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, self.get_id())
        else:
            wf2['conflux_url'] = 'http://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, self.get_id())
        message = self.REQUEST.TLS('wfreminder_complete_message') % wf2

        msg = email.MIMEText.MIMEText(message.encode('UTF8'))
        del msg['Content-Type']
        msg['Content-Type'] = 'text/plain; charset="utf-8"'
        msg['From'] = str(email.Header.Header(u'%s <%s@%s>' % (_Conf.APP_NAME, _Conf.APP_EMAIL_NAME, _Conf.SMTPSERVER)))
        to = []
        if self.REQUEST.USER.get_person(self.REQUEST).get('e_mail'):
            to.append(str(email.Header.Header(self.REQUEST.USER.get_person(self.REQUEST).get('e_mail'))))
            msg['To'] = to[-1]
        for relid in _Utils.sql_parse_array(self.REQUEST, self.get('related_persons')):
            p = _RootObject.dispatch_item(self.REQUEST, relid)
            if p.get('e_mail'):
                to.append(str(email.Header.Header(p.get('e_mail'))))
                msg['To'] = to[-1]
        msg['Subject'] = str(email.Header.Header(subject))

        try:        
            server = smtplib.SMTP(_Conf.SMTPSERVER)
            server.sendmail(str(msg['from']), to, msg.as_string())
            server.quit()
        except:
            pass

    def nexttask(self, task = None):
        if not self.get('workflow_flags') & WORKFLOW_SERIAL:
            return

        if task and task.get('workflow_sequence_id') is not None:
            SQL = """SELECT todo_id FROM todos WHERE workflow_id=%d AND workflow_sequence_id > %d AND percent_complete < 100 ORDER BY workflow_sequence_id ASC LIMIT 1""" % (self.get_id(), task.get('workflow_sequence_id'))
        else:
            SQL = """SELECT todo_id FROM todos WHERE workflow_id=%d AND percent_complete < 100 ORDER BY workflow_sequence_id ASC LIMIT 1""" % self.get_id()
        self.REQUEST.db.execute(SQL)
        res = self.REQUEST.db.dictfetchone()
        if not res: # No following task.
            return
        nexttask = _RootObject.dispatch_item(self.REQUEST, res['todo_id'])
         
        subject = self.REQUEST.TLS('wfreminder_nexttask_subject') % self.get('workflow_title')
        ns = {}
        for key in self.object_fields.keys():
            ns[key] = self.get(key)
            if ns[key] is None:
                ns[key] = ''
            elif key in ['workflow_due_time', 'workflow_start_time'] and ns[key]:
                ns[key] = self.REQUEST.iso2userdate(ns[key])
            elif key in ['workflow_due_time', 'workflow_start_time']:
                ns[key] = ''
        for key in nexttask.object_fields.keys():
            ns[key] = nexttask.get(key)
            if ns[key] is None:
                ns[key] = ''
            elif key in ['due_time', 'start_time'] and ns[key]:
                ns[key] = self.REQUEST.iso2userdate(ns[key])
            elif key in ['workflow_due_time', 'workflow_start_time']:
                ns[key] = ''
        if self.REQUEST.is_https:
            ns['conflux_url'] = 'https://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, nexttask.get_id())
            ns['conflux_url2'] = 'https://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, self.get_id())
        else:
            ns['conflux_url'] = 'http://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, nexttask.get_id())
            ns['conflux_url2'] = 'http://%s%s%s.py' % (self.REQUEST.mod_req.server.server_hostname, _Conf.BASE_URL, self.get_id())
        message = self.REQUEST.TLS('wfreminder_nexttask_message') % ns

        msg = email.MIMEText.MIMEText(message.encode('UTF8'))
        del msg['Content-Type']
        msg['Content-Type'] = 'text/plain; charset="utf-8"'
        msg['From'] = str(email.Header.Header(u'%s <%s@%s>' % (_Conf.APP_NAME, _Conf.APP_EMAIL_NAME, _Conf.SMTPSERVER)))
        msg['Subject'] = str(email.Header.Header(subject))
        to = []
        if self.REQUEST.USER.get_person(self.REQUEST).get('e_mail'):
            to.append(str(email.Header.Header(self.REQUEST.USER.get_person(self.REQUEST).get('e_mail'))))
            msg['To'] = to[-1]
        
        self.REQUEST.su_by_id(_Conf.SUPERUSER)
        for relid in _Utils.sql_parse_array(self.REQUEST, self.get('related_persons')):
            p = _RootObject.dispatch_item(self.REQUEST, relid)
            if p.get('e_mail'):
                to.append(str(email.Header.Header(p.get('e_mail'))))
                msg['To'] = to[-1]
        for relid in _Utils.sql_parse_array(self.REQUEST, nexttask.get('related_persons')):
            p = _RootObject.dispatch_item(self.REQUEST, relid)
            if p.get('e_mail'):
                to.append(str(email.Header.Header(p.get('e_mail'))))
                msg['To'] = to[-1]
        self.REQUEST.unsu()

        try:        
            server = smtplib.SMTP(_Conf.SMTPSERVER)
            server.sendmail(str(msg['from']), to, msg.as_string())
            server.quit()
        except:
            pass

    def AfterDeleteHook(self):
         self.REQUEST.db.execute("""SELECT i.item_id FROM items i, todos t WHERE i.item_id=t.todo_id AND t.workflow_id=%d""" % self.get_id())
         res = self.REQUEST.db.fetchall()
         for row in res:
             delobj = _RootObject.dispatch_item(self.REQUEST, row[0])
             delobj.delete()
