import _Event, _Utils, _Conf, _RootObject, _InitTypes
import mx.DateTime

def get_event_next_repeat(REQUEST, event_id):

    SQL = """SELECT * FROM events e, items i WHERE e.event_id=i.item_id AND e.start_stamp = (SELECT MAX(e2.start_stamp) FROM events e2 WHERE e2.master_id=%d) AND (e.master_id=%d)""" % (event_id,event_id)
    REQUEST.db.execute(SQL.encode('UTF8'))
    result = REQUEST.db.dictfetchone()
    if not result:
        SQL = """SELECT * FROM events e, items i WHERE e.event_id=i.item_id AND e.event_id=%d""" % (event_id)
        REQUEST.db.execute(SQL.encode('UTF8'))
        result = REQUEST.db.dictfetchone()
        if not result:
            return None

    NOW = mx.DateTime.DateTime(result['start_stamp'].year, result['start_stamp'].month, result['start_stamp'].day, result['start_stamp'].hour, result['start_stamp'].minute, 1)

    if result['repeat_type'] is None:
        return result['start_stamp']

    repeat_type = result['repeat_type']
    repeat_interval = result['repeat_interval']
    if not repeat_interval:
        return result['start_stamp']

    if repeat_type == _Event.REPEAT_DAY:
        interval = mx.DateTime.DateTimeDelta(repeat_interval)
        start = result['start_stamp']
        end = result['end_stamp']

        if repeat_interval > 0:
            count = 0
            while 1:
                if start >= NOW:
                    result['start_stamp'] = start
                    result['end_stamp'] = end
                    break
                elif count > _Conf.MAX_REPEAT_EVENTS:
                    break
                count = count + 1
                start = start + interval
                end = end + interval

    elif repeat_type == _Event.REPEAT_WEEK:
        days_repeat = [0, 0, 0, 0, 0, 0, 0]
        for i in range(7):
            if result['dayofweek'] & _Event.DAYS[i]:
                days_repeat[i] = 1

        interval = mx.DateTime.DateTimeDelta(repeat_interval*7)
        start = result['start_stamp']
        end = result['end_stamp']

        count = 0
        if repeat_interval > 0 and 1 in days_repeat:
            event_weekday = result['start_stamp'].day_of_week
            if 1 in days_repeat[event_weekday+1:]:
                next_day = days_repeat[event_weekday+1:].index(1)+event_weekday+1
                additional = next_day - event_weekday
                start = start + mx.DateTime.DateTimeDelta(additional)
                end = end + mx.DateTime.DateTimeDelta(additional)
            else:
                start = start + interval
                end = end + interval
                next_day = days_repeat.index(1)
                additional = next_day - event_weekday
                start = start + mx.DateTime.DateTimeDelta(additional)
                end = end + mx.DateTime.DateTimeDelta(additional)


    elif repeat_type == _Event.REPEAT_MONTH:
        start = result['start_stamp']
        end = result['end_stamp']

        if repeat_interval > 0 and result['dayofmonth']>0:
            event_day = result['start_stamp'].day
            if event_day < result['dayofmonth']:
                additional = result['dayofmonth'] - event_day
                start = start + mx.DateTime.DateTimeDelta(additional)
                end = end + mx.DateTime.DateTimeDelta(additional)
            else:
                temp = mx.DateTime.DateTime(start.year, start.month, 1)
                for i in range(_Conf.MAX_REPEAT_EVENTS):
                    try:
                        temp = mx.DateTime.DateTime(temp.year, temp.month+repeat_interval, result['dayofmonth'])
                        break
                    except mx.DateTime.RangeError:
                        if temp.month+repeat_interval>12:
                            try:
                                temp = mx.DateTime.DateTime(temp.year+1, temp.month+repeat_interval-12, result['dayofmonth'])
                                break
                            except:
                                temp = mx.DateTime.DateTime(temp.year+1, temp.month+repeat_interval-12, 1)
                                continue
                        else:
                            temp = mx.DateTime.DateTime(temp.year, temp.month+repeat_interval, 1)
                            continue
                start = temp + mx.DateTime.DateTimeDelta(0, start.hour, start.minute)
                end = temp + mx.DateTime.DateTimeDelta(0, end.hour, end.minute)

    elif repeat_type == _Event.REPEAT_YEAR:
        start = result['start_stamp']
        end = result['end_stamp']

        count = 0
        if repeat_interval > 0:
            while 1:
                if count > _Conf.MAX_REPEAT_EVENTS:
                    break
                count = count + 1
                try:
                    start = mx.DateTime.DateTime(start.year+repeat_interval, result['monthofyear'], result['dayofmonth'], start.hour, start.minute)
                    end = mx.DateTime.DateTime(end.year+repeat_interval, result['monthofyear'], result['dayofmonth'], end.hour, end.minute)
                    break
                except:
                    start = mx.DateTime.DateTime(start.year+repeat_interval, result['monthofyear'])
                    end = start
                    continue
    return (start, end)

def insert_events(REQUEST, event_id, insert_count):
    inserted = 0
    obj = _RootObject.dispatch_item(REQUEST, event_id)
    while(inserted<insert_count):
        child_obj = _Event.Event(REQUEST, _InitTypes.INIT_TYPE_NEW)
        child_obj.set('event_name', obj.get('event_name'))
        child_obj.set('event_priority', obj.get('event_priority'))
        child_obj.set('event_activity', obj.get('event_activity'))
        child_obj.set('description', obj.get('description'))
        child_obj.set('comments', obj.get('comments'))
        child_obj.set('remind_type', obj.get('remind_type'))
        child_obj.set('related_persons', _Utils.sql_parse_array(REQUEST, obj.get('related_persons')))
        child_obj.set('seen_persons', _Utils.sql_parse_array(REQUEST, obj.get('seen_persons')))
        child_obj.set('accepted_persons', _Utils.sql_parse_array(REQUEST, obj.get('accepted_persons')))
        child_obj.set('rejected_persons', _Utils.sql_parse_array(REQUEST, obj.get('rejected_persons')))
        child_obj.set('repeat_interval', obj.get('repeat_interval'))
        child_obj.set('dayofweek', obj.get('dayofweek'))
        child_obj.set('dayofmonth', obj.get('dayofmonth'))
        child_obj.set('monthofyear', obj.get('monthofyear'))
        child_obj.set('repeat_type', obj.get('repeat_type'))
        child_obj.set('related_groups', _Utils.sql_parse_array(REQUEST, obj.get('related_groups')))
        child_obj.set('event_flags', obj.get('event_flags'))
        child_obj.set('master_id', event_id)
        # ajad
        tpl = get_event_next_repeat(REQUEST, event_id)
        child_obj.set('start_stamp', tpl[0])
        child_obj.set('end_stamp',   tpl[1])
        original_remind_time = obj.get('remind_time')
        if original_remind_time and original_remind_time.delta:
            child_obj.set('remind_time', original_remind_time.delta)
        REQUEST.su_by_id(obj.get('creator_id'))
        try:
            child_obj.set('parent_id', obj.get('parent_id'))
            child_obj.save()
        finally:
            REQUEST.unsu()
        inserted = inserted + 1
        REQUEST.db.commit()